#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: swim_trigger_activation_v1
short_description: Resource module for Swim Trigger Activation V1
description:
- Manage operation create of the resource Swim Trigger Activation V1.
- Activates a software image on a given device. Software image must be present in the device flash.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  payload:
    description: Swim Trigger Activation's payload.
    elements: dict
    suboptions:
      activateLowerImageVersion:
        description: ActivateLowerImageVersion flag.
        type: bool
      deviceUpgradeMode:
        description: Swim Trigger Activation's deviceUpgradeMode.
        type: str
      deviceUuid:
        description: Swim Trigger Activation's deviceUuid.
        type: str
      distributeIfNeeded:
        description: DistributeIfNeeded flag.
        type: bool
      imageUuidList:
        description: Swim Trigger Activation's imageUuidList.
        elements: str
        type: list
      smuImageUuidList:
        description: Swim Trigger Activation's smuImageUuidList.
        elements: str
        type: list
    type: list
  scheduleValidate:
    description: ScheduleValidate query parameter. ScheduleValidate, validates data
      before schedule (Optional).
    type: bool
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Software Image Management (SWIM) TriggerSoftwareImageActivationV1
  description: Complete reference of the TriggerSoftwareImageActivationV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!trigger-software-image-activation
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.trigger_software_image_activation_v1,

  - Paths used are
    post /dna/intent/api/v1/image/activation/device,

"""

EXAMPLES = r"""
- name: Create
  cisco.dnac.swim_trigger_activation_v1:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: '{{my_headers | from_json}}'
    payload:
    - activateLowerImageVersion: true
      deviceUpgradeMode: string
      deviceUuid: string
      distributeIfNeeded: true
      imageUuidList:
      - string
      smuImageUuidList:
      - string
    scheduleValidate: true

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)


DOCUMENTATION = r"""
---
module: compliance_check_run
short_description: Resource module for Compliance Check Run
description:
- This module represents an alias of the module compliance_check_run_v1
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  categories:
    description: Category can have any value among 'INTENT'(mapped to compliance types
      NETWORK_SETTINGS,NETWORK_PROFILE,WORKFLOW,FABRIC,APPLICATION_VISIBILITY), 'RUNNING_CONFIG'
      , 'IMAGE' , 'PSIRT' , 'EOX' , 'NETWORK_SETTINGS'.
    elements: str
    type: list
  deviceUuids:
    description: UUID of the device.
    elements: str
    type: list
  triggerFull:
    description: If it is true then compliance will be triggered for all categories.
      If it is false then compliance will be triggered for categories mentioned in categories
      section .
    type: bool
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Compliance RunComplianceV1
  description: Complete reference of the RunComplianceV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!run-compliance
notes:
  - SDK Method used are
    compliance.Compliance.run_compliance_v1,

  - Paths used are
    post /dna/intent/api/v1/compliance/,
  - It should be noted that this module is an alias of compliance_check_run_v1

"""

EXAMPLES = r"""
- name: Create
  cisco.dnac.compliance_check_run:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    categories:
    - string
    deviceUuids:
    - string
    triggerFull: true

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "taskId": "string",
        "url": "string"
      }
    }
"""



# -*- coding: utf-8 -*-
# Copyright 2020 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function


__metaclass__ = type

#############################################
#                WARNING                    #
#############################################
#
# This file is auto generated by the resource
#   module builder playbook.
#
# Do not edit this file manually.
#
# Changes to this file will be over written
#   by the resource module builder.
#
# Changes should be made in the model used to
#   generate this file or in the resource module
#   builder template.
#
#############################################

"""
The arg spec for the cisco.ios_ospfv3 module
"""


class Ospfv3Args(object):  # pylint: disable=R0903
    """The arg spec for the cisco.ios_ospfv3 module"""

    def __init__(self, **kwargs):
        pass

    argument_spec = {
        "config": {
            "type": "dict",
            "options": {
                "processes": {
                    "type": "list",
                    "elements": "dict",
                    "options": {
                        "process_id": {"required": True, "type": "int"},
                        "address_family": {
                            "type": "list",
                            "elements": "dict",
                            "options": {
                                "afi": {"type": "str", "choices": ["ipv4", "ipv6"]},
                                "unicast": {"type": "bool"},
                                "vrf": {"type": "str"},
                                "adjacency": {
                                    "type": "dict",
                                    "options": {
                                        "min_adjacency": {"type": "int"},
                                        "none": {"type": "bool"},
                                        "max_adjacency": {"type": "int"},
                                        "disable": {"type": "bool"},
                                    },
                                },
                                "areas": {
                                    "type": "list",
                                    "elements": "dict",
                                    "options": {
                                        "area_id": {"type": "str"},
                                        "authentication": {
                                            "type": "dict",
                                            "options": {
                                                "key_chain": {"type": "str", "no_log": True},
                                                "null": {"type": "bool"},
                                            },
                                        },
                                        "default_cost": {"type": "int"},
                                        "filter_list": {
                                            "type": "list",
                                            "elements": "dict",
                                            "options": {
                                                "name": {"type": "str"},
                                                "direction": {
                                                    "type": "str",
                                                    "choices": ["in", "out"],
                                                    "required": True,
                                                },
                                            },
                                        },
                                        "normal": {"type": "bool"},
                                        "nssa": {
                                            "type": "dict",
                                            "options": {
                                                "set": {"type": "bool"},
                                                "default_information_originate": {
                                                    "type": "dict",
                                                    "options": {
                                                        "metric": {"type": "int"},
                                                        "metric_type": {
                                                            "type": "int",
                                                            "choices": [1, 2],
                                                        },
                                                        "nssa_only": {"type": "bool"},
                                                    },
                                                },
                                                "no_redistribution": {"type": "bool"},
                                                "no_summary": {"type": "bool"},
                                                "translate": {
                                                    "type": "str",
                                                    "choices": ["always", "suppress-fa"],
                                                },
                                            },
                                        },
                                        "ranges": {
                                            "type": "list",
                                            "elements": "dict",
                                            "options": {
                                                "address": {"type": "str"},
                                                "netmask": {"type": "str"},
                                                "advertise": {"type": "bool"},
                                                "cost": {"type": "int"},
                                                "not_advertise": {"type": "bool"},
                                            },
                                        },
                                        "sham_link": {
                                            "type": "dict",
                                            "options": {
                                                "source": {"type": "str"},
                                                "destination": {"type": "str"},
                                                "authentication": {
                                                    "type": "dict",
                                                    "options": {
                                                        "key_chain": {
                                                            "type": "str",
                                                            "no_log": True,
                                                        },
                                                        "null": {"type": "bool"},
                                                    },
                                                },
                                                "cost": {"type": "int"},
                                                "ttl_security": {"type": "int"},
                                            },
                                        },
                                        "stub": {
                                            "type": "dict",
                                            "options": {
                                                "set": {"type": "bool"},
                                                "no_summary": {"type": "bool"},
                                            },
                                        },
                                    },
                                },
                                "authentication": {
                                    "type": "dict",
                                    "options": {
                                        "deployment": {"type": "bool"},
                                        "normal": {"type": "bool"},
                                    },
                                },
                                "auto_cost": {
                                    "type": "dict",
                                    "options": {
                                        "set": {"type": "bool"},
                                        "reference_bandwidth": {"type": "int"},
                                    },
                                },
                                "bfd": {
                                    "type": "dict",
                                    "options": {
                                        "all_interfaces": {"type": "bool"},
                                        "disable": {"type": "bool"},
                                    },
                                },
                                "capability": {"type": "bool"},
                                "compatible": {
                                    "type": "dict",
                                    "options": {
                                        "rfc1583": {"type": "bool"},
                                        "rfc1587": {"type": "bool"},
                                        "rfc5243": {"type": "bool"},
                                    },
                                },
                                "default_information": {
                                    "type": "dict",
                                    "options": {
                                        "originate": {"type": "bool"},
                                        "always": {"type": "bool"},
                                        "metric": {"type": "int"},
                                        "metric_type": {"type": "int"},
                                        "route_map": {"type": "str"},
                                    },
                                },
                                "default_metric": {"type": "int"},
                                "discard_route": {
                                    "type": "dict",
                                    "options": {
                                        "sham_link": {"type": "bool"},
                                        "external": {"type": "bool"},
                                        "internal": {"type": "bool"},
                                    },
                                },
                                "distance": {"type": "int"},
                                "distribute_list": {
                                    "type": "dict",
                                    "options": {
                                        "acls": {
                                            "type": "list",
                                            "elements": "dict",
                                            "options": {
                                                "name": {"type": "str", "required": True},
                                                "direction": {
                                                    "type": "str",
                                                    "required": True,
                                                    "choices": ["in", "out"],
                                                },
                                                "interface": {"type": "str"},
                                                "protocol": {"type": "str"},
                                            },
                                        },
                                        "prefix": {
                                            "type": "dict",
                                            "options": {
                                                "name": {"type": "str", "required": True},
                                                "gateway_name": {"type": "str"},
                                                "direction": {
                                                    "type": "str",
                                                    "required": True,
                                                    "choices": ["in", "out"],
                                                },
                                                "interface": {"type": "str"},
                                                "protocol": {"type": "str"},
                                            },
                                        },
                                        "route_map": {
                                            "type": "dict",
                                            "options": {"name": {"type": "str", "required": True}},
                                        },
                                    },
                                },
                                "event_log": {
                                    "type": "dict",
                                    "options": {
                                        "enable": {"type": "bool"},
                                        "one_shot": {"type": "bool"},
                                        "pause": {"type": "bool"},
                                        "size": {"type": "int"},
                                    },
                                },
                                "graceful_restart": {
                                    "type": "dict",
                                    "options": {
                                        "enable": {"type": "bool"},
                                        "disable": {"type": "bool"},
                                        "strict_lsa_checking": {"type": "bool"},
                                    },
                                },
                                "interface_id": {
                                    "type": "dict",
                                    "options": {
                                        "ios_if_index": {"type": "bool"},
                                        "snmp_if_index": {"type": "bool"},
                                    },
                                },
                                "limit": {
                                    "type": "dict",
                                    "options": {
                                        "dc": {
                                            "type": "dict",
                                            "options": {
                                                "number": {"type": "int"},
                                                "disable": {"type": "bool"},
                                            },
                                        },
                                        "non_dc": {
                                            "type": "dict",
                                            "options": {
                                                "number": {"type": "int"},
                                                "disable": {"type": "bool"},
                                            },
                                        },
                                    },
                                },
                                "local_rib_criteria": {
                                    "type": "dict",
                                    "options": {
                                        "enable": {"type": "bool"},
                                        "forwarding_address": {"type": "bool"},
                                        "inter_area_summary": {"type": "bool"},
                                        "nssa_translation": {"type": "bool"},
                                    },
                                },
                                "log_adjacency_changes": {
                                    "type": "dict",
                                    "options": {
                                        "set": {"type": "bool"},
                                        "detail": {"type": "bool"},
                                    },
                                },
                                "manet": {
                                    "type": "dict",
                                    "options": {
                                        "cache": {
                                            "type": "dict",
                                            "options": {
                                                "acknowledgement": {"type": "int"},
                                                "update": {"type": "int"},
                                            },
                                        },
                                        "hello": {
                                            "type": "dict",
                                            "options": {
                                                "multicast": {"type": "bool"},
                                                "unicast": {"type": "bool"},
                                            },
                                        },
                                        "peering": {
                                            "type": "dict",
                                            "options": {
                                                "set": {"type": "bool"},
                                                "disable": {"type": "bool"},
                                                "per_interface": {"type": "bool"},
                                                "redundancy": {"type": "int"},
                                            },
                                        },
                                        "willingness": {"type": "int"},
                                    },
                                },
                                "max_lsa": {
                                    "type": "dict",
                                    "options": {
                                        "number": {"type": "int"},
                                        "threshold_value": {"type": "int"},
                                        "ignore_count": {"type": "int"},
                                        "ignore_time": {"type": "int"},
                                        "reset_time": {"type": "int"},
                                        "warning_only": {"type": "bool"},
                                    },
                                },
                                "max_metric": {
                                    "type": "dict",
                                    "options": {
                                        "disable": {"type": "bool"},
                                        "external_lsa": {"type": "int"},
                                        "inter_area_lsas": {"type": "int"},
                                        "on_startup": {
                                            "type": "dict",
                                            "options": {
                                                "time": {"type": "int"},
                                                "wait_for_bgp": {"type": "bool"},
                                            },
                                        },
                                        "stub_prefix_lsa": {"type": "bool"},
                                    },
                                },
                                "maximum_paths": {"type": "int"},
                                "passive_interface": {"type": "str"},
                                "prefix_suppression": {
                                    "type": "dict",
                                    "options": {
                                        "enable": {"type": "bool"},
                                        "disable": {"type": "bool"},
                                    },
                                },
                                "queue_depth": {
                                    "type": "dict",
                                    "options": {
                                        "hello": {
                                            "type": "dict",
                                            "options": {
                                                "max_packets": {"type": "int"},
                                                "unlimited": {"type": "bool"},
                                            },
                                        },
                                        "update": {
                                            "type": "dict",
                                            "options": {
                                                "max_packets": {"type": "int"},
                                                "unlimited": {"type": "bool"},
                                            },
                                        },
                                    },
                                },
                                "router_id": {"type": "str"},
                                "shutdown": {
                                    "type": "dict",
                                    "options": {
                                        "enable": {"type": "bool"},
                                        "disable": {"type": "bool"},
                                    },
                                },
                                "summary_prefix": {
                                    "type": "dict",
                                    "options": {
                                        "address": {"type": "str"},
                                        "mask": {"type": "str"},
                                        "not_advertise": {"type": "bool"},
                                        "nssa_only": {"type": "bool"},
                                        "tag": {"type": "int"},
                                    },
                                },
                                "timers": {
                                    "type": "dict",
                                    "options": {
                                        "lsa": {"type": "int"},
                                        "manet": {
                                            "type": "dict",
                                            "options": {
                                                "cache": {
                                                    "type": "dict",
                                                    "options": {
                                                        "acknowledgement": {"type": "int"},
                                                        "redundancy": {"type": "int"},
                                                    },
                                                },
                                                "hello": {"type": "bool"},
                                                "peering": {
                                                    "type": "dict",
                                                    "options": {
                                                        "set": {"type": "bool"},
                                                        "per_interface": {"type": "bool"},
                                                        "redundancy": {"type": "int"},
                                                    },
                                                },
                                                "willingness": {"type": "int"},
                                            },
                                        },
                                        "pacing": {
                                            "type": "dict",
                                            "options": {
                                                "flood": {"type": "int"},
                                                "lsa_group": {"type": "int"},
                                                "retransmission": {"type": "int"},
                                            },
                                        },
                                        "throttle": {
                                            "type": "dict",
                                            "options": {
                                                "lsa": {
                                                    "type": "dict",
                                                    "options": {
                                                        "first_delay": {"type": "int"},
                                                        "min_delay": {"type": "int"},
                                                        "max_delay": {"type": "int"},
                                                    },
                                                },
                                                "spf": {
                                                    "type": "dict",
                                                    "options": {
                                                        "receive_delay": {"type": "int"},
                                                        "between_delay": {"type": "int"},
                                                        "max_delay": {"type": "int"},
                                                    },
                                                },
                                            },
                                        },
                                    },
                                },
                            },
                        },
                        "adjacency": {
                            "type": "dict",
                            "options": {
                                "min_adjacency": {"type": "int"},
                                "max_adjacency": {"type": "int"},
                                "none": {"type": "bool"},
                            },
                        },
                        "areas": {
                            "type": "list",
                            "elements": "dict",
                            "options": {
                                "area_id": {"type": "str"},
                                "authentication": {
                                    "type": "dict",
                                    "options": {
                                        "key_chain": {"type": "str", "no_log": True},
                                        "ipsec": {
                                            "type": "dict",
                                            "options": {
                                                "spi": {"type": "int"},
                                                "md5": {"type": "int"},
                                                "sha1": {"type": "int"},
                                                "hex_string": {"type": "str"},
                                            },
                                        },
                                    },
                                },
                                "default_cost": {"type": "int"},
                                "nssa": {
                                    "type": "dict",
                                    "options": {
                                        "set": {"type": "bool"},
                                        "default_information_originate": {
                                            "type": "dict",
                                            "options": {
                                                "metric": {"type": "int"},
                                                "metric_type": {"type": "int", "choices": [1, 2]},
                                                "nssa_only": {"type": "bool"},
                                            },
                                        },
                                        "no_redistribution": {"type": "bool"},
                                        "no_summary": {"type": "bool"},
                                        "translate": {
                                            "type": "str",
                                            "choices": ["always", "suppress-fa"],
                                        },
                                    },
                                },
                                "stub": {
                                    "type": "dict",
                                    "options": {
                                        "set": {"type": "bool"},
                                        "no_summary": {"type": "bool"},
                                    },
                                },
                            },
                        },
                        "authentication": {"type": "bool"},
                        "auto_cost": {
                            "type": "dict",
                            "options": {
                                "set": {"type": "bool"},
                                "reference_bandwidth": {"type": "int"},
                            },
                        },
                        "bfd": {"type": "bool"},
                        "compatible": {
                            "type": "dict",
                            "options": {
                                "rfc1583": {"type": "bool"},
                                "rfc1587": {"type": "bool"},
                                "rfc5243": {"type": "bool"},
                            },
                        },
                        "event_log": {
                            "type": "dict",
                            "options": {
                                "enable": {"type": "bool"},
                                "one_shot": {"type": "bool"},
                                "pause": {"type": "bool"},
                                "size": {"type": "int"},
                            },
                        },
                        "graceful_restart": {
                            "type": "dict",
                            "options": {
                                "disable": {"type": "bool"},
                                "strict_lsa_checking": {"type": "bool"},
                            },
                        },
                        "help": {"type": "bool"},
                        "interface_id": {"type": "bool"},
                        "limit": {
                            "type": "dict",
                            "options": {
                                "dc": {
                                    "type": "dict",
                                    "options": {
                                        "number": {"type": "int"},
                                        "disable": {"type": "bool"},
                                    },
                                },
                                "non_dc": {
                                    "type": "dict",
                                    "options": {
                                        "number": {"type": "int"},
                                        "disable": {"type": "bool"},
                                    },
                                },
                            },
                        },
                        "local_rib_criteria": {
                            "type": "dict",
                            "options": {
                                "enable": {"type": "bool"},
                                "forwarding_address": {"type": "bool"},
                                "inter_area_summary": {"type": "bool"},
                                "nssa_translation": {"type": "bool"},
                            },
                        },
                        "log_adjacency_changes": {
                            "type": "dict",
                            "options": {"set": {"type": "bool"}, "detail": {"type": "bool"}},
                        },
                        "manet": {
                            "type": "dict",
                            "options": {
                                "cache": {
                                    "type": "dict",
                                    "options": {
                                        "acknowledgement": {"type": "int"},
                                        "redundancy": {"type": "int"},
                                    },
                                },
                                "hello": {"type": "bool"},
                                "peering": {
                                    "type": "dict",
                                    "options": {
                                        "set": {"type": "bool"},
                                        "per_interface": {"type": "bool"},
                                        "redundancy": {"type": "int"},
                                    },
                                },
                                "willingness": {"type": "int"},
                            },
                        },
                        "max_lsa": {
                            "type": "dict",
                            "options": {
                                "number": {"type": "int"},
                                "threshold_value": {"type": "int"},
                                "ignore_count": {"type": "int"},
                                "ignore_time": {"type": "int"},
                                "reset_time": {"type": "int"},
                                "warning_only": {"type": "bool"},
                            },
                        },
                        "max_metric": {
                            "type": "dict",
                            "options": {
                                "router_lsa": {"type": "bool", "required": True},
                                "external_lsa": {"type": "int"},
                                "include_stub": {"type": "bool"},
                                "on_startup": {
                                    "type": "dict",
                                    "options": {
                                        "time": {"type": "int"},
                                        "wait_for_bgp": {"type": "bool"},
                                    },
                                },
                                "summary_lsa": {"type": "int"},
                            },
                        },
                        "passive_interface": {"type": "str"},
                        "prefix_suppression": {"type": "bool"},
                        "queue_depth": {
                            "type": "dict",
                            "options": {
                                "hello": {
                                    "type": "dict",
                                    "options": {
                                        "max_packets": {"type": "int"},
                                        "unlimited": {"type": "bool"},
                                    },
                                },
                            },
                        },
                        "router_id": {"type": "str"},
                        "shutdown": {"type": "bool"},
                        "timers": {
                            "type": "dict",
                            "options": {
                                "lsa": {"type": "int"},
                                "manet": {
                                    "type": "dict",
                                    "options": {
                                        "cache": {
                                            "type": "dict",
                                            "options": {
                                                "acknowledgement": {"type": "int"},
                                                "redundancy": {"type": "int"},
                                            },
                                        },
                                        "hello": {"type": "bool"},
                                        "peering": {
                                            "type": "dict",
                                            "options": {
                                                "set": {"type": "bool"},
                                                "per_interface": {"type": "bool"},
                                                "redundancy": {"type": "int"},
                                            },
                                        },
                                        "willingness": {"type": "int"},
                                    },
                                },
                                "pacing": {
                                    "type": "dict",
                                    "options": {
                                        "flood": {"type": "int"},
                                        "lsa_group": {"type": "int"},
                                        "retransmission": {"type": "int"},
                                    },
                                },
                                "throttle": {
                                    "type": "dict",
                                    "options": {
                                        "lsa": {
                                            "type": "dict",
                                            "options": {
                                                "first_delay": {"type": "int"},
                                                "min_delay": {"type": "int"},
                                                "max_delay": {"type": "int"},
                                            },
                                        },
                                        "spf": {
                                            "type": "dict",
                                            "options": {
                                                "receive_delay": {"type": "int"},
                                                "between_delay": {"type": "int"},
                                                "max_delay": {"type": "int"},
                                            },
                                        },
                                    },
                                },
                            },
                        },
                    },
                },
            },
        },
        "running_config": {"type": "str"},
        "state": {
            "type": "str",
            "choices": [
                "merged",
                "replaced",
                "overridden",
                "deleted",
                "gathered",
                "parsed",
                "rendered",
            ],
            "default": "merged",
        },
    }  # pylint: disable=C0301



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: custom_issue_definitions_v1_info
short_description: Information module for Custom Issue Definitions V1
description:
- Get all Custom Issue Definitions V1.
- >
   Retrieve the existing syslog-based custom issue definitions. The supported filters are id, name, profileId,
   definition enable status, priority, severity, facility and mnemonic. The issue definition configurations may vary
   across profiles, hence specifying the profile Id in the query parameter is important and the default profile is
   global.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
    - >
      Id query parameter. The custom issue definition identifier and unique identifier across the profile.Examples
      id=6bef213c-19ca-4170-8375-b694e251101c (single entity uuid requested)
      id=6bef213c-19ca-4170-8375-b694e251101c&id=19ca-4170-8375-b694e251101c-6bef213c (multiple Id request in the
      query param).
    type: str
  profileId:
    description:
    - >
      ProfileId query parameter. The profile identifier to fetch the profile associated custom issue definitions.
      The default is global. For the custom profile, it is profile UUID. Example
      3fa85f64-5717-4562-b3fc-2c963f66afa6.
    type: str
  name:
    description:
    - Name query parameter. The list of UDI issue names.
    type: str
  priority:
    description:
    - >
      Priority query parameter. The Issue priority value, possible values are P1, P2, P3, P4. P1 A critical issue
      that needs immediate attention and can have a wide impact on network operations. P2 A major issue that can
      potentially impact multiple devices or clients. P3 A minor issue that has a localized or minimal impact. P4
      A warning issue that may not be an immediate problem but addressing it can optimize the network performance.
    type: str
  isEnabled:
    description:
    - IsEnabled query parameter. The enable status of the custom issue definition, either true or false.
    type: bool
  severity:
    description:
    - >
      Severity query parameter. The syslog severity level. 0 Emergency 1 Alert, 2 Critical. 3 Error, 4 Warning, 5
      Notice, 6 Info. Examples severity=1&severity=2 (multi value support with & separator).
    type: float
  facility:
    description:
    - Facility query parameter. The syslog facility name.
    type: str
  mnemonic:
    description:
    - Mnemonic query parameter. The syslog mnemonic name.
    type: str
  limit:
    description:
    - Limit query parameter. The maximum number of records to return.
    type: float
  offset:
    description:
    - >
      Offset query parameter. Specifies the starting point within all records returned by the API. It's one based
      offset. The starting value is 1.
    type: float
  sortBy:
    description:
    - SortBy query parameter. A field within the response to sort by.
    type: str
  order:
    description:
    - Order query parameter. The sort order of the field ascending or descending.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Issues GetAllTheCustomIssueDefinitionsBasedOnTheGivenFiltersV1
  description: Complete reference of the GetAllTheCustomIssueDefinitionsBasedOnTheGivenFiltersV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!get-all-the-custom-issue-definitions-based-on-the-given-filters
notes:
  - SDK Method used are
    issues.Issues.get_all_the_custom_issue_definitions_based_on_the_given_filters_v1,

  - Paths used are
    get /dna/intent/api/v1/customIssueDefinitions,

"""

EXAMPLES = r"""
- name: Get all Custom Issue Definitions V1
  cisco.dnac.custom_issue_definitions_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    profileId: string
    name: string
    priority: string
    isEnabled: True
    severity: 0
    facility: string
    mnemonic: string
    limit: 0
    offset: 0
    sortBy: string
    order: string
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "name": "string",
          "description": "string",
          "profileId": "string",
          "triggerId": "string",
          "rules": [
            {
              "type": "string",
              "severity": 0,
              "facility": "string",
              "mnemonic": "string",
              "pattern": "string",
              "occurrences": 0,
              "durationInMinutes": 0
            }
          ],
          "isEnabled": true,
          "priority": "string",
          "isDeletable": true,
          "isNotificationEnabled": true,
          "createdTime": 0,
          "lastUpdatedTime": 0
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: system_issue_definitions_id_v1_info
short_description: Information module for System Issue Definitions Id V1
description:
- Get System Issue Definitions Id V1 by id.
- >
   Get system issue defintion for the given id. Definition includes all properties from IssueTriggerDefinition schema
   by default. For detailed information about the usage of the API, please refer to the Open API specification
   document - https //github.com/cisco-en-programmability/catalyst-center-api-
   specs/blob/main/Assurance/CE_Cat_Center_Org-issueAndHealthDefinitions-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
    - Id path parameter. Issue trigger definition id.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Issues GetIssueTriggerDefinitionForGivenIdV1
  description: Complete reference of the GetIssueTriggerDefinitionForGivenIdV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!get-issue-trigger-definition-for-given-id
notes:
  - SDK Method used are
    issues.Issues.get_issue_trigger_definition_for_given_id_v1,

  - Paths used are
    get /dna/intent/api/v1/systemIssueDefinitions/{id},

"""

EXAMPLES = r"""
- name: Get System Issue Definitions Id V1 by id
  cisco.dnac.system_issue_definitions_id_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "displayName": "string",
        "description": "string",
        "priority": "string",
        "defaultPriority": "string",
        "deviceType": "string",
        "issueEnabled": true,
        "profileId": "string",
        "definitionStatus": "string",
        "categoryName": "string",
        "synchronizeToHealthThreshold": true,
        "thresholdValue": 0,
        "lastModified": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sda_port_assignments_count_v1_info
short_description: Information module for Sda Port Assignments Count V1
description:
- Get all Sda Port Assignments Count V1.
- Returns the count of port assignments that match the provided query parameters.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  fabricId:
    description:
    - FabricId query parameter. ID of the fabric the device is assigned to.
    type: str
  networkDeviceId:
    description:
    - NetworkDeviceId query parameter. Network device ID of the port assignment.
    type: str
  interfaceName:
    description:
    - InterfaceName query parameter. Interface name of the port assignment.
    type: str
  dataVlanName:
    description:
    - DataVlanName query parameter. Data VLAN name of the port assignment.
    type: str
  voiceVlanName:
    description:
    - VoiceVlanName query parameter. Voice VLAN name of the port assignment.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for SDA GetPortAssignmentCountV1
  description: Complete reference of the GetPortAssignmentCountV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!get-port-assignment-count
notes:
  - SDK Method used are
    sda.Sda.get_port_assignment_count_v1,

  - Paths used are
    get /dna/intent/api/v1/sda/portAssignments/count,

"""

EXAMPLES = r"""
- name: Get all Sda Port Assignments Count V1
  cisco.dnac.sda_port_assignments_count_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    fabricId: string
    networkDeviceId: string
    interfaceName: string
    dataVlanName: string
    voiceVlanName: string
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: client_detail_v1_info
short_description: Information module for Client Detail V1
description:
- Get all Client Detail V1.
- Returns detailed Client information retrieved by Mac Address for any given point of time.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  macAddress:
    description:
    - MacAddress query parameter. MAC Address of the client.
    type: str
  timestamp:
    description:
    - Timestamp query parameter. Epoch time(in milliseconds) when the Client health data is required.
    type: float
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Clients GetClientDetailV1
  description: Complete reference of the GetClientDetailV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!get-client-detail
notes:
  - SDK Method used are
    clients.Clients.get_client_detail_v1,

  - Paths used are
    get /dna/intent/api/v1/client-detail,

"""

EXAMPLES = r"""
- name: Get all Client Detail V1
  cisco.dnac.client_detail_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    macAddress: string
    timestamp: 0
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "detail": {
        "id": "string",
        "connectionStatus": "string",
        "tracked": "string",
        "hostType": "string",
        "userId": "string",
        "duid": "string",
        "identifier": "string",
        "hostName": "string",
        "hostOs": "string",
        "hostVersion": "string",
        "subType": "string",
        "firmwareVersion": "string",
        "deviceVendor": "string",
        "deviceForm": "string",
        "salesCode": "string",
        "countryCode": "string",
        "lastUpdated": 0,
        "healthScore": [
          {
            "healthType": "string",
            "reason": "string",
            "score": 0
          }
        ],
        "hostMac": "string",
        "hostIpV4": "string",
        "hostIpV6": [
          "string"
        ],
        "authType": "string",
        "vlanId": 0,
        "l3VirtualNetwork": "string",
        "l2VirtualNetwork": "string",
        "vnid": 0,
        "upnId": "string",
        "upnName": "string",
        "ssid": "string",
        "frequency": "string",
        "channel": "string",
        "apGroup": "string",
        "sgt": "string",
        "location": "string",
        "clientConnection": "string",
        "connectedDevice": [
          {
            "type": "string",
            "name": "string",
            "mac": "string",
            "id": "string",
            "ip address": "string",
            "mgmtIp": "string",
            "band": "string",
            "mode": "string"
          }
        ],
        "issueCount": 0,
        "rssi": "string",
        "rssiThreshold": "string",
        "rssiIsInclude": "string",
        "avgRssi": "string",
        "snr": "string",
        "snrThreshold": "string",
        "snrIsInclude": "string",
        "avgSnr": "string",
        "dataRate": "string",
        "txBytes": "string",
        "rxBytes": "string",
        "dnsResponse": "string",
        "dnsRequest": "string",
        "onboarding": {
          "averageRunDuration": "string",
          "maxRunDuration": "string",
          "averageAssocDuration": "string",
          "maxAssocDuration": "string",
          "averageAuthDuration": "string",
          "maxAuthDuration": "string",
          "averageDhcpDuration": "string",
          "maxDhcpDuration": "string",
          "aaaServerIp": "string",
          "dhcpServerIp": "string",
          "authDoneTime": 0,
          "assocDoneTime": 0,
          "dhcpDoneTime": 0,
          "assocRootcauseList": [
            "string"
          ],
          "aaaRootcauseList": [
            "string"
          ],
          "dhcpRootcauseList": [
            "string"
          ],
          "otherRootcauseList": [
            "string"
          ],
          "latestRootCauseList": [
            "string"
          ]
        },
        "clientType": "string",
        "onboardingTime": 0,
        "port": "string",
        "iosCapable": true,
        "usage": 0,
        "linkSpeed": 0,
        "linkThreshold": "string",
        "remoteEndDuplexMode": "string",
        "txLinkError": 0,
        "rxLinkError": 0,
        "txRate": 0,
        "rxRate": 0,
        "rxRetryPct": "string",
        "versionTime": 0,
        "dot11Protocol": "string",
        "slotId": 0,
        "dot11ProtocolCapability": "string",
        "privateMac": true,
        "dhcpServerIp": "string",
        "aaaServerIp": "string",
        "aaaServerTransaction": 0,
        "aaaServerFailedTransaction": 0,
        "aaaServerSuccessTransaction": 0,
        "aaaServerLatency": 0,
        "aaaServerMABLatency": 0,
        "aaaServerEAPLatency": 0,
        "dhcpServerTransaction": 0,
        "dhcpServerFailedTransaction": 0,
        "dhcpServerSuccessTransaction": 0,
        "dhcpServerLatency": 0,
        "dhcpServerDOLatency": 0,
        "dhcpServerRALatency": 0,
        "maxRoamingDuration": "string",
        "upnOwner": "string",
        "connectedUpn": "string",
        "connectedUpnOwner": "string",
        "connectedUpnId": "string",
        "isGuestUPNEndpoint": true,
        "wlcName": "string",
        "wlcUuid": "string",
        "sessionDuration": "string",
        "intelCapable": true,
        "hwModel": "string",
        "powerType": "string",
        "modelName": "string",
        "bridgeVMMode": "string",
        "dhcpNakIp": "string",
        "dhcpDeclineIp": "string",
        "portDescription": "string",
        "latencyVoice": 0,
        "latencyVideo": 0,
        "latencyBg": 0,
        "latencyBe": 0,
        "trustScore": "string",
        "trustDetails": "string"
      },
      "connectionInfo": {
        "hostType": "string",
        "nwDeviceName": "string",
        "nwDeviceMac": "string",
        "protocol": "string",
        "band": "string",
        "spatialStream": "string",
        "channel": "string",
        "channelWidth": "string",
        "wmm": "string",
        "uapsd": "string",
        "timestamp": 0
      },
      "topology": {
        "nodes": [
          {
            "role": "string",
            "name": "string",
            "id": "string",
            "description": "string",
            "deviceType": "string",
            "platformId": "string",
            "family": "string",
            "ip": "string",
            "ipv6": [
              "string"
            ],
            "softwareVersion": "string",
            "userId": "string",
            "nodeType": "string",
            "radioFrequency": "string",
            "clients": 0,
            "count": 0,
            "healthScore": 0,
            "level": 0,
            "fabricGroup": "string",
            "fabricRole": [
              "string"
            ],
            "connectedDevice": "string",
            "stackType": "string"
          }
        ],
        "links": [
          {
            "source": "string",
            "linkStatus": "string",
            "sourceLinkStatus": "string",
            "targetLinkStatus": "string",
            "label": [
              "string"
            ],
            "target": "string",
            "id": "string",
            "portUtilization": 0,
            "sourceInterfaceName": "string",
            "targetInterfaceName": "string",
            "sourceDuplexInfo": "string",
            "targetDuplexInfo": "string",
            "sourcePortMode": "string",
            "targetPortMode": "string",
            "sourceAdminStatus": "string",
            "targetAdminStatus": "string",
            "apRadioAdminStatus": "string",
            "apRadioOperStatus": "string",
            "sourcePortVLANInfo": "string",
            "targetPortVLANInfo": "string",
            "interfaceDetails": [
              {
                "clientMacAddress": "string",
                "connectedDeviceIntName": "string",
                "duplex": "string",
                "portMode": "string",
                "adminStatus": "string"
              }
            ]
          }
        ]
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: path_trace_v1_info
short_description: Information module for Path Trace V1
description:
- Get all Path Trace V1.
- Get Path Trace V1 by id.
- Returns a summary of all flow analyses stored. Results can be filtered by specified parameters.
- Returns result of a previously requested flow analysis by its Flow Analysis id.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  periodicRefresh:
    description:
    - PeriodicRefresh query parameter. Is analysis periodically refreshed?.
    type: bool
  sourceIP:
    description:
    - SourceIP query parameter. Source IP address.
    type: str
  destIP:
    description:
    - DestIP query parameter. Destination IP address.
    type: str
  sourcePort:
    description:
    - SourcePort query parameter. Source port.
    type: float
  destPort:
    description:
    - DestPort query parameter. Destination port.
    type: float
  gtCreateTime:
    description:
    - GtCreateTime query parameter. Analyses requested after this time.
    type: float
  ltCreateTime:
    description:
    - LtCreateTime query parameter. Analyses requested before this time.
    type: float
  protocol:
    description:
    - Protocol query parameter.
    type: str
  status:
    description:
    - Status query parameter.
    type: str
  taskId:
    description:
    - TaskId query parameter. Task ID.
    type: str
  lastUpdateTime:
    description:
    - LastUpdateTime query parameter. Last update time.
    type: float
  limit:
    description:
    - Limit query parameter. Number of resources returned.
    type: float
  offset:
    description:
    - Offset query parameter. Start index of resources returned (1-based).
    type: float
  order:
    description:
    - Order query parameter. Order by this field.
    type: str
  sortBy:
    description:
    - SortBy query parameter. Sort by this field.
    type: str
  flowAnalysisId:
    description:
    - FlowAnalysisId path parameter. Flow analysis request id.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Path Trace RetrievesAllPreviousPathtracesSummaryV1
  description: Complete reference of the RetrievesAllPreviousPathtracesSummaryV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!retrieves-all-previous-pathtraces-summary
- name: Cisco DNA Center documentation for Path Trace RetrievesPreviousPathtraceV1
  description: Complete reference of the RetrievesPreviousPathtraceV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!retrieves-previous-pathtrace
notes:
  - SDK Method used are
    path_trace.PathTrace.retrieves_all_previous_pathtraces_summary_v1,
    path_trace.PathTrace.retrieves_previous_pathtrace_v1,

  - Paths used are
    get /dna/intent/api/v1/flow-analysis,
    get /dna/intent/api/v1/flow-analysis/{flowAnalysisId},

"""

EXAMPLES = r"""
- name: Get all Path Trace V1
  cisco.dnac.path_trace_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    periodicRefresh: True
    sourceIP: string
    destIP: string
    sourcePort: 0
    destPort: 0
    gtCreateTime: 0
    ltCreateTime: 0
    protocol: string
    status: string
    taskId: string
    lastUpdateTime: 0
    limit: 0
    offset: 0
    order: string
    sortBy: string
  register: result

- name: Get Path Trace V1 by id
  cisco.dnac.path_trace_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    flowAnalysisId: string
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "detailedStatus": {
          "aclTraceCalculation": "string",
          "aclTraceCalculationFailureReason": "string"
        },
        "lastUpdate": "string",
        "networkElements": [
          {
            "accuracyList": [
              {
                "percent": 0,
                "reason": "string"
              }
            ],
            "detailedStatus": {
              "aclTraceCalculation": "string",
              "aclTraceCalculationFailureReason": "string"
            },
            "deviceStatistics": {
              "cpuStatistics": {
                "fiveMinUsageInPercentage": 0,
                "fiveSecsUsageInPercentage": 0,
                "oneMinUsageInPercentage": 0,
                "refreshedAt": 0
              },
              "memoryStatistics": {
                "memoryUsage": 0,
                "refreshedAt": 0,
                "totalMemory": 0
              }
            },
            "deviceStatsCollection": "string",
            "deviceStatsCollectionFailureReason": "string",
            "egressPhysicalInterface": {
              "aclAnalysis": {
                "aclName": "string",
                "matchingAces": [
                  {
                    "ace": "string",
                    "matchingPorts": [
                      {
                        "ports": [
                          {
                            "destPorts": [
                              "string"
                            ],
                            "sourcePorts": [
                              "string"
                            ]
                          }
                        ],
                        "protocol": "string"
                      }
                    ],
                    "result": "string"
                  }
                ],
                "result": "string"
              },
              "id": "string",
              "interfaceStatistics": {
                "adminStatus": "string",
                "inputPackets": 0,
                "inputQueueCount": 0,
                "inputQueueDrops": 0,
                "inputQueueFlushes": 0,
                "inputQueueMaxDepth": 0,
                "inputRatebps": 0,
                "operationalStatus": "string",
                "outputDrop": 0,
                "outputPackets": 0,
                "outputQueueCount": 0,
                "outputQueueDepth": 0,
                "outputRatebps": 0,
                "refreshedAt": 0
              },
              "interfaceStatsCollection": "string",
              "interfaceStatsCollectionFailureReason": "string",
              "name": "string",
              "pathOverlayInfo": [
                {
                  "controlPlane": "string",
                  "dataPacketEncapsulation": "string",
                  "destIp": "string",
                  "destPort": "string",
                  "protocol": "string",
                  "sourceIp": "string",
                  "sourcePort": "string",
                  "vxlanInfo": {
                    "dscp": "string",
                    "vnid": "string"
                  }
                }
              ],
              "qosStatistics": [
                {
                  "classMapName": "string",
                  "dropRate": 0,
                  "numBytes": 0,
                  "numPackets": 0,
                  "offeredRate": 0,
                  "queueBandwidthbps": "string",
                  "queueDepth": 0,
                  "queueNoBufferDrops": 0,
                  "queueTotalDrops": 0,
                  "refreshedAt": 0
                }
              ],
              "qosStatsCollection": "string",
              "qosStatsCollectionFailureReason": "string",
              "usedVlan": "string",
              "vrfName": "string"
            },
            "egressVirtualInterface": {
              "aclAnalysis": {
                "aclName": "string",
                "matchingAces": [
                  {
                    "ace": "string",
                    "matchingPorts": [
                      {
                        "ports": [
                          {
                            "destPorts": [
                              "string"
                            ],
                            "sourcePorts": [
                              "string"
                            ]
                          }
                        ],
                        "protocol": "string"
                      }
                    ],
                    "result": "string"
                  }
                ],
                "result": "string"
              },
              "id": "string",
              "interfaceStatistics": {
                "adminStatus": "string",
                "inputPackets": 0,
                "inputQueueCount": 0,
                "inputQueueDrops": 0,
                "inputQueueFlushes": 0,
                "inputQueueMaxDepth": 0,
                "inputRatebps": 0,
                "operationalStatus": "string",
                "outputDrop": 0,
                "outputPackets": 0,
                "outputQueueCount": 0,
                "outputQueueDepth": 0,
                "outputRatebps": 0,
                "refreshedAt": 0
              },
              "interfaceStatsCollection": "string",
              "interfaceStatsCollectionFailureReason": "string",
              "name": "string",
              "pathOverlayInfo": [
                {
                  "controlPlane": "string",
                  "dataPacketEncapsulation": "string",
                  "destIp": "string",
                  "destPort": "string",
                  "protocol": "string",
                  "sourceIp": "string",
                  "sourcePort": "string",
                  "vxlanInfo": {
                    "dscp": "string",
                    "vnid": "string"
                  }
                }
              ],
              "qosStatistics": [
                {
                  "classMapName": "string",
                  "dropRate": 0,
                  "numBytes": 0,
                  "numPackets": 0,
                  "offeredRate": 0,
                  "queueBandwidthbps": "string",
                  "queueDepth": 0,
                  "queueNoBufferDrops": 0,
                  "queueTotalDrops": 0,
                  "refreshedAt": 0
                }
              ],
              "qosStatsCollection": "string",
              "qosStatsCollectionFailureReason": "string",
              "usedVlan": "string",
              "vrfName": "string"
            },
            "flexConnect": {
              "authentication": "string",
              "dataSwitching": "string",
              "egressAclAnalysis": {
                "aclName": "string",
                "matchingAces": [
                  {
                    "ace": "string",
                    "matchingPorts": [
                      {
                        "ports": [
                          {
                            "destPorts": [
                              "string"
                            ],
                            "sourcePorts": [
                              "string"
                            ]
                          }
                        ],
                        "protocol": "string"
                      }
                    ],
                    "result": "string"
                  }
                ],
                "result": "string"
              },
              "ingressAclAnalysis": {
                "aclName": "string",
                "matchingAces": [
                  {
                    "ace": "string",
                    "matchingPorts": [
                      {
                        "ports": [
                          {
                            "destPorts": [
                              "string"
                            ],
                            "sourcePorts": [
                              "string"
                            ]
                          }
                        ],
                        "protocol": "string"
                      }
                    ],
                    "result": "string"
                  }
                ],
                "result": "string"
              },
              "wirelessLanControllerId": "string",
              "wirelessLanControllerName": "string"
            },
            "id": "string",
            "ingressPhysicalInterface": {
              "aclAnalysis": {
                "aclName": "string",
                "matchingAces": [
                  {
                    "ace": "string",
                    "matchingPorts": [
                      {
                        "ports": [
                          {
                            "destPorts": [
                              "string"
                            ],
                            "sourcePorts": [
                              "string"
                            ]
                          }
                        ],
                        "protocol": "string"
                      }
                    ],
                    "result": "string"
                  }
                ],
                "result": "string"
              },
              "id": "string",
              "interfaceStatistics": {
                "adminStatus": "string",
                "inputPackets": 0,
                "inputQueueCount": 0,
                "inputQueueDrops": 0,
                "inputQueueFlushes": 0,
                "inputQueueMaxDepth": 0,
                "inputRatebps": 0,
                "operationalStatus": "string",
                "outputDrop": 0,
                "outputPackets": 0,
                "outputQueueCount": 0,
                "outputQueueDepth": 0,
                "outputRatebps": 0,
                "refreshedAt": 0
              },
              "interfaceStatsCollection": "string",
              "interfaceStatsCollectionFailureReason": "string",
              "name": "string",
              "pathOverlayInfo": [
                {
                  "controlPlane": "string",
                  "dataPacketEncapsulation": "string",
                  "destIp": "string",
                  "destPort": "string",
                  "protocol": "string",
                  "sourceIp": "string",
                  "sourcePort": "string",
                  "vxlanInfo": {
                    "dscp": "string",
                    "vnid": "string"
                  }
                }
              ],
              "qosStatistics": [
                {
                  "classMapName": "string",
                  "dropRate": 0,
                  "numBytes": 0,
                  "numPackets": 0,
                  "offeredRate": 0,
                  "queueBandwidthbps": "string",
                  "queueDepth": 0,
                  "queueNoBufferDrops": 0,
                  "queueTotalDrops": 0,
                  "refreshedAt": 0
                }
              ],
              "qosStatsCollection": "string",
              "qosStatsCollectionFailureReason": "string",
              "usedVlan": "string",
              "vrfName": "string"
            },
            "ingressVirtualInterface": {
              "aclAnalysis": {
                "aclName": "string",
                "matchingAces": [
                  {
                    "ace": "string",
                    "matchingPorts": [
                      {
                        "ports": [
                          {
                            "destPorts": [
                              "string"
                            ],
                            "sourcePorts": [
                              "string"
                            ]
                          }
                        ],
                        "protocol": "string"
                      }
                    ],
                    "result": "string"
                  }
                ],
                "result": "string"
              },
              "id": "string",
              "interfaceStatistics": {
                "adminStatus": "string",
                "inputPackets": 0,
                "inputQueueCount": 0,
                "inputQueueDrops": 0,
                "inputQueueFlushes": 0,
                "inputQueueMaxDepth": 0,
                "inputRatebps": 0,
                "operationalStatus": "string",
                "outputDrop": 0,
                "outputPackets": 0,
                "outputQueueCount": 0,
                "outputQueueDepth": 0,
                "outputRatebps": 0,
                "refreshedAt": 0
              },
              "interfaceStatsCollection": "string",
              "interfaceStatsCollectionFailureReason": "string",
              "name": "string",
              "pathOverlayInfo": [
                {
                  "controlPlane": "string",
                  "dataPacketEncapsulation": "string",
                  "destIp": "string",
                  "destPort": "string",
                  "protocol": "string",
                  "sourceIp": "string",
                  "sourcePort": "string",
                  "vxlanInfo": {
                    "dscp": "string",
                    "vnid": "string"
                  }
                }
              ],
              "qosStatistics": [
                {
                  "classMapName": "string",
                  "dropRate": 0,
                  "numBytes": 0,
                  "numPackets": 0,
                  "offeredRate": 0,
                  "queueBandwidthbps": "string",
                  "queueDepth": 0,
                  "queueNoBufferDrops": 0,
                  "queueTotalDrops": 0,
                  "refreshedAt": 0
                }
              ],
              "qosStatsCollection": "string",
              "qosStatsCollectionFailureReason": "string",
              "usedVlan": "string",
              "vrfName": "string"
            },
            "ip": "string",
            "linkInformationSource": "string",
            "name": "string",
            "perfMonCollection": "string",
            "perfMonCollectionFailureReason": "string",
            "perfMonStatistics": [
              {
                "byteRate": 0,
                "destIpAddress": "string",
                "destPort": "string",
                "inputInterface": "string",
                "ipv4DSCP": "string",
                "ipv4TTL": 0,
                "outputInterface": "string",
                "packetBytes": 0,
                "packetCount": 0,
                "packetLoss": 0,
                "packetLossPercentage": 0,
                "protocol": "string",
                "refreshedAt": 0,
                "rtpJitterMax": 0,
                "rtpJitterMean": 0,
                "rtpJitterMin": 0,
                "sourceIpAddress": "string",
                "sourcePort": "string"
              }
            ],
            "role": "string",
            "ssid": "string",
            "tunnels": [
              "string"
            ],
            "type": "string",
            "wlanId": "string"
          }
        ],
        "networkElementsInfo": [
          {
            "accuracyList": [
              {
                "percent": 0,
                "reason": "string"
              }
            ],
            "detailedStatus": {
              "aclTraceCalculation": "string",
              "aclTraceCalculationFailureReason": "string"
            },
            "deviceStatistics": {
              "cpuStatistics": {
                "fiveMinUsageInPercentage": 0,
                "fiveSecsUsageInPercentage": 0,
                "oneMinUsageInPercentage": 0,
                "refreshedAt": 0
              },
              "memoryStatistics": {
                "memoryUsage": 0,
                "refreshedAt": 0,
                "totalMemory": 0
              }
            },
            "deviceStatsCollection": "string",
            "deviceStatsCollectionFailureReason": "string",
            "egressInterface": {
              "physicalInterface": {
                "aclAnalysis": {
                  "aclName": "string",
                  "matchingAces": [
                    {
                      "ace": "string",
                      "matchingPorts": [
                        {
                          "ports": [
                            {
                              "destPorts": [
                                "string"
                              ],
                              "sourcePorts": [
                                "string"
                              ]
                            }
                          ],
                          "protocol": "string"
                        }
                      ],
                      "result": "string"
                    }
                  ],
                  "result": "string"
                },
                "id": "string",
                "interfaceStatistics": {
                  "adminStatus": "string",
                  "inputPackets": 0,
                  "inputQueueCount": 0,
                  "inputQueueDrops": 0,
                  "inputQueueFlushes": 0,
                  "inputQueueMaxDepth": 0,
                  "inputRatebps": 0,
                  "operationalStatus": "string",
                  "outputDrop": 0,
                  "outputPackets": 0,
                  "outputQueueCount": 0,
                  "outputQueueDepth": 0,
                  "outputRatebps": 0,
                  "refreshedAt": 0
                },
                "interfaceStatsCollection": "string",
                "interfaceStatsCollectionFailureReason": "string",
                "name": "string",
                "pathOverlayInfo": [
                  {
                    "controlPlane": "string",
                    "dataPacketEncapsulation": "string",
                    "destIp": "string",
                    "destPort": "string",
                    "protocol": "string",
                    "sourceIp": "string",
                    "sourcePort": "string",
                    "vxlanInfo": {
                      "dscp": "string",
                      "vnid": "string"
                    }
                  }
                ],
                "qosStatistics": [
                  {
                    "classMapName": "string",
                    "dropRate": 0,
                    "numBytes": 0,
                    "numPackets": 0,
                    "offeredRate": 0,
                    "queueBandwidthbps": "string",
                    "queueDepth": 0,
                    "queueNoBufferDrops": 0,
                    "queueTotalDrops": 0,
                    "refreshedAt": 0
                  }
                ],
                "qosStatsCollection": "string",
                "qosStatsCollectionFailureReason": "string",
                "usedVlan": "string",
                "vrfName": "string"
              },
              "virtualInterface": [
                {
                  "aclAnalysis": {
                    "aclName": "string",
                    "matchingAces": [
                      {
                        "ace": "string",
                        "matchingPorts": [
                          {
                            "ports": [
                              {
                                "destPorts": [
                                  "string"
                                ],
                                "sourcePorts": [
                                  "string"
                                ]
                              }
                            ],
                            "protocol": "string"
                          }
                        ],
                        "result": "string"
                      }
                    ],
                    "result": "string"
                  },
                  "id": "string",
                  "interfaceStatistics": {
                    "adminStatus": "string",
                    "inputPackets": 0,
                    "inputQueueCount": 0,
                    "inputQueueDrops": 0,
                    "inputQueueFlushes": 0,
                    "inputQueueMaxDepth": 0,
                    "inputRatebps": 0,
                    "operationalStatus": "string",
                    "outputDrop": 0,
                    "outputPackets": 0,
                    "outputQueueCount": 0,
                    "outputQueueDepth": 0,
                    "outputRatebps": 0,
                    "refreshedAt": 0
                  },
                  "interfaceStatsCollection": "string",
                  "interfaceStatsCollectionFailureReason": "string",
                  "name": "string",
                  "pathOverlayInfo": [
                    {
                      "controlPlane": "string",
                      "dataPacketEncapsulation": "string",
                      "destIp": "string",
                      "destPort": "string",
                      "protocol": "string",
                      "sourceIp": "string",
                      "sourcePort": "string",
                      "vxlanInfo": {
                        "dscp": "string",
                        "vnid": "string"
                      }
                    }
                  ],
                  "qosStatistics": [
                    {
                      "classMapName": "string",
                      "dropRate": 0,
                      "numBytes": 0,
                      "numPackets": 0,
                      "offeredRate": 0,
                      "queueBandwidthbps": "string",
                      "queueDepth": 0,
                      "queueNoBufferDrops": 0,
                      "queueTotalDrops": 0,
                      "refreshedAt": 0
                    }
                  ],
                  "qosStatsCollection": "string",
                  "qosStatsCollectionFailureReason": "string",
                  "usedVlan": "string",
                  "vrfName": "string"
                }
              ]
            },
            "flexConnect": {
              "authentication": "string",
              "dataSwitching": "string",
              "egressAclAnalysis": {
                "aclName": "string",
                "matchingAces": [
                  {
                    "ace": "string",
                    "matchingPorts": [
                      {
                        "ports": [
                          {
                            "destPorts": [
                              "string"
                            ],
                            "sourcePorts": [
                              "string"
                            ]
                          }
                        ],
                        "protocol": "string"
                      }
                    ],
                    "result": "string"
                  }
                ],
                "result": "string"
              },
              "ingressAclAnalysis": {
                "aclName": "string",
                "matchingAces": [
                  {
                    "ace": "string",
                    "matchingPorts": [
                      {
                        "ports": [
                          {
                            "destPorts": [
                              "string"
                            ],
                            "sourcePorts": [
                              "string"
                            ]
                          }
                        ],
                        "protocol": "string"
                      }
                    ],
                    "result": "string"
                  }
                ],
                "result": "string"
              },
              "wirelessLanControllerId": "string",
              "wirelessLanControllerName": "string"
            },
            "id": "string",
            "ingressInterface": {
              "physicalInterface": {
                "aclAnalysis": {
                  "aclName": "string",
                  "matchingAces": [
                    {
                      "ace": "string",
                      "matchingPorts": [
                        {
                          "ports": [
                            {
                              "destPorts": [
                                "string"
                              ],
                              "sourcePorts": [
                                "string"
                              ]
                            }
                          ],
                          "protocol": "string"
                        }
                      ],
                      "result": "string"
                    }
                  ],
                  "result": "string"
                },
                "id": "string",
                "interfaceStatistics": {
                  "adminStatus": "string",
                  "inputPackets": 0,
                  "inputQueueCount": 0,
                  "inputQueueDrops": 0,
                  "inputQueueFlushes": 0,
                  "inputQueueMaxDepth": 0,
                  "inputRatebps": 0,
                  "operationalStatus": "string",
                  "outputDrop": 0,
                  "outputPackets": 0,
                  "outputQueueCount": 0,
                  "outputQueueDepth": 0,
                  "outputRatebps": 0,
                  "refreshedAt": 0
                },
                "interfaceStatsCollection": "string",
                "interfaceStatsCollectionFailureReason": "string",
                "name": "string",
                "pathOverlayInfo": [
                  {
                    "controlPlane": "string",
                    "dataPacketEncapsulation": "string",
                    "destIp": "string",
                    "destPort": "string",
                    "protocol": "string",
                    "sourceIp": "string",
                    "sourcePort": "string",
                    "vxlanInfo": {
                      "dscp": "string",
                      "vnid": "string"
                    }
                  }
                ],
                "qosStatistics": [
                  {
                    "classMapName": "string",
                    "dropRate": 0,
                    "numBytes": 0,
                    "numPackets": 0,
                    "offeredRate": 0,
                    "queueBandwidthbps": "string",
                    "queueDepth": 0,
                    "queueNoBufferDrops": 0,
                    "queueTotalDrops": 0,
                    "refreshedAt": 0
                  }
                ],
                "qosStatsCollection": "string",
                "qosStatsCollectionFailureReason": "string",
                "usedVlan": "string",
                "vrfName": "string"
              },
              "virtualInterface": [
                {
                  "aclAnalysis": {
                    "aclName": "string",
                    "matchingAces": [
                      {
                        "ace": "string",
                        "matchingPorts": [
                          {
                            "ports": [
                              {
                                "destPorts": [
                                  "string"
                                ],
                                "sourcePorts": [
                                  "string"
                                ]
                              }
                            ],
                            "protocol": "string"
                          }
                        ],
                        "result": "string"
                      }
                    ],
                    "result": "string"
                  },
                  "id": "string",
                  "interfaceStatistics": {
                    "adminStatus": "string",
                    "inputPackets": 0,
                    "inputQueueCount": 0,
                    "inputQueueDrops": 0,
                    "inputQueueFlushes": 0,
                    "inputQueueMaxDepth": 0,
                    "inputRatebps": 0,
                    "operationalStatus": "string",
                    "outputDrop": 0,
                    "outputPackets": 0,
                    "outputQueueCount": 0,
                    "outputQueueDepth": 0,
                    "outputRatebps": 0,
                    "refreshedAt": 0
                  },
                  "interfaceStatsCollection": "string",
                  "interfaceStatsCollectionFailureReason": "string",
                  "name": "string",
                  "pathOverlayInfo": [
                    {
                      "controlPlane": "string",
                      "dataPacketEncapsulation": "string",
                      "destIp": "string",
                      "destPort": "string",
                      "protocol": "string",
                      "sourceIp": "string",
                      "sourcePort": "string",
                      "vxlanInfo": {
                        "dscp": "string",
                        "vnid": "string"
                      }
                    }
                  ],
                  "qosStatistics": [
                    {
                      "classMapName": "string",
                      "dropRate": 0,
                      "numBytes": 0,
                      "numPackets": 0,
                      "offeredRate": 0,
                      "queueBandwidthbps": "string",
                      "queueDepth": 0,
                      "queueNoBufferDrops": 0,
                      "queueTotalDrops": 0,
                      "refreshedAt": 0
                    }
                  ],
                  "qosStatsCollection": "string",
                  "qosStatsCollectionFailureReason": "string",
                  "usedVlan": "string",
                  "vrfName": "string"
                }
              ]
            },
            "ip": "string",
            "linkInformationSource": "string",
            "name": "string",
            "perfMonCollection": "string",
            "perfMonCollectionFailureReason": "string",
            "perfMonitorStatistics": [
              {
                "byteRate": 0,
                "destIpAddress": "string",
                "destPort": "string",
                "inputInterface": "string",
                "ipv4DSCP": "string",
                "ipv4TTL": 0,
                "outputInterface": "string",
                "packetBytes": 0,
                "packetCount": 0,
                "packetLoss": 0,
                "packetLossPercentage": 0,
                "protocol": "string",
                "refreshedAt": 0,
                "rtpJitterMax": 0,
                "rtpJitterMean": 0,
                "rtpJitterMin": 0,
                "sourceIpAddress": "string",
                "sourcePort": "string"
              }
            ],
            "role": "string",
            "ssid": "string",
            "tunnels": [
              "string"
            ],
            "type": "string",
            "wlanId": "string"
          }
        ],
        "properties": [
          "string"
        ],
        "request": {
          "controlPath": true,
          "createTime": 0,
          "destIP": "string",
          "destPort": "string",
          "failureReason": "string",
          "id": "string",
          "inclusions": [
            "string"
          ],
          "lastUpdateTime": 0,
          "periodicRefresh": true,
          "protocol": "string",
          "sourceIP": "string",
          "sourcePort": "string",
          "status": "string",
          "previousFlowAnalysisId": "string"
        }
      },
      "version": "string"
    }
"""



# (c) 2018, Ansible Inc,
# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
# SPDX-License-Identifier: GPL-3.0-or-later

from __future__ import absolute_import, division, print_function


__metaclass__ = type

import hashlib
import os
import re
import uuid

from ansible.errors import AnsibleError
from ansible.module_utils._text import to_bytes, to_text
from ansible.module_utils.connection import Connection, ConnectionError
from ansible.module_utils.six.moves.urllib.parse import urlsplit
from ansible.plugins.action import ActionBase
from ansible.utils.display import Display


display = Display()


class ActionModule(ActionBase):
    def run(self, tmp=None, task_vars=None):
        changed = False
        socket_path = None
        self._get_network_os(task_vars)
        persistent_connection = self._play_context.connection.split(".")[-1]

        result = super(ActionModule, self).run(task_vars=task_vars)

        if persistent_connection != "network_cli":
            # It is supported only with network_cli
            result["failed"] = True
            result["msg"] = (
                "connection type %s is not valid for net_get module,"
                " please use fully qualified name of network_cli connection type"
                % self._play_context.connection
            )
            return result

        try:
            src = self._task.args["src"]
        except KeyError as exc:
            return {
                "failed": True,
                "msg": "missing required argument: %s" % exc,
            }

        # Get destination file if specified
        dest = self._task.args.get("dest")

        if dest is None:
            dest = self._get_default_dest(src)
        else:
            dest = self._handle_dest_path(dest)

        # Get proto
        proto = self._task.args.get("protocol")
        if proto is None:
            proto = "scp"

        if socket_path is None:
            socket_path = self._connection.socket_path

        conn = Connection(socket_path)
        sock_timeout = conn.get_option("persistent_command_timeout")

        try:
            changed = self._handle_existing_file(conn, src, dest, proto, sock_timeout)
            if changed is False:
                result["changed"] = changed
                result["destination"] = dest
                return result
        except Exception as exc:
            result["msg"] = "Warning: %s idempotency check failed. Check dest" % exc

        try:
            conn.get_file(source=src, destination=dest, proto=proto, timeout=sock_timeout)
        except Exception as exc:
            result["failed"] = True
            result["msg"] = "Exception received: %s" % exc

        result["changed"] = changed
        result["destination"] = dest
        return result

    def _handle_dest_path(self, dest):
        working_path = self._get_working_path()

        if os.path.isabs(dest) or urlsplit("dest").scheme:
            dst = dest
        else:
            dst = self._loader.path_dwim_relative(working_path, "", dest)

        return dst

    def _get_src_filename_from_path(self, src_path):
        filename_list = re.split("/|:", src_path)
        return filename_list[-1]

    def _get_default_dest(self, src_path):
        dest_path = self._get_working_path()
        src_fname = self._get_src_filename_from_path(src_path)
        filename = "%s/%s" % (dest_path, src_fname)
        return filename

    def _handle_existing_file(self, conn, source, dest, proto, timeout):
        """
        Determines whether the source and destination file match.

        :return: False if source and dest both exist and have matching sha1 sums, True otherwise.
        """
        if not os.path.exists(dest):
            return True

        cwd = self._loader.get_basedir()
        filename = str(uuid.uuid4())
        tmp_dest_file = os.path.join(cwd, filename)
        try:
            conn.get_file(
                source=source,
                destination=tmp_dest_file,
                proto=proto,
                timeout=timeout,
            )
        except ConnectionError as exc:
            error = to_text(exc)
            if error.endswith("No such file or directory"):
                if os.path.exists(tmp_dest_file):
                    os.remove(tmp_dest_file)
                return True

        try:
            with open(tmp_dest_file, "r") as f:
                new_content = f.read()
            with open(dest, "r") as f:
                old_content = f.read()
        except (IOError, OSError):
            os.remove(tmp_dest_file)
            raise

        sha1 = hashlib.sha1()
        old_content_b = to_bytes(old_content, errors="surrogate_or_strict")
        sha1.update(old_content_b)
        checksum_old = sha1.digest()

        sha1 = hashlib.sha1()
        new_content_b = to_bytes(new_content, errors="surrogate_or_strict")
        sha1.update(new_content_b)
        checksum_new = sha1.digest()
        os.remove(tmp_dest_file)
        if checksum_old == checksum_new:
            return False
        return True

    def _get_working_path(self):
        cwd = self._loader.get_basedir()
        if self._task._role is not None:
            cwd = self._task._role._role_path
        return cwd

    def _get_network_os(self, task_vars):
        if "network_os" in self._task.args and self._task.args["network_os"]:
            display.vvvv("Getting network OS from task argument")
            network_os = self._task.args["network_os"]
        elif self._play_context.network_os:
            display.vvvv("Getting network OS from inventory")
            network_os = self._play_context.network_os
        elif (
            "network_os" in task_vars.get("ansible_facts", {})
            and task_vars["ansible_facts"]["network_os"]
        ):
            display.vvvv("Getting network OS from fact")
            network_os = task_vars["ansible_facts"]["network_os"]
        else:
            raise AnsibleError("ansible_network_os must be specified on this host")

        return network_os



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_controllers_wireless_mobility_groups_mobility_provision_v1
short_description: Resource module for Wireless Controllers Wireless Mobility Groups Mobility Provision V1
description:
- Manage operation create of the resource Wireless Controllers Wireless Mobility Groups Mobility Provision V1.
- This API is used to provision/deploy wireless mobility into Cisco wireless controllers.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  dataLinkEncryption:
    description: A secure link in which data is encrypted using CAPWAP DTLS protocol
      can be established between two controllers. This value will be applied to all
      peers during POST operation.
    type: bool
  dtlsHighCipher:
    description: DTLS High Cipher.
    type: bool
  macAddress:
    description: Device mobility MAC Address. Allowed formats are 0a0b.0c01.0211, 0a0b0c010211,
      0a 0b 0c 01 02 11.
    type: str
  managementIp:
    description: Self device wireless Management IP.
    type: str
  mobilityGroupName:
    description: Self device Group Name. Must be alphanumeric without {!,<,space,?/'}
      and maximum of 31 characters.
    type: str
  mobilityPeers:
    description: Wireless Controllers Wireless Mobility Groups Mobility Provision's
      mobilityPeers.
    elements: dict
    suboptions:
      deviceSeries:
        description: Indicates peer device mobility belongs to AireOS or IOX-XE family.
          0 - indicates AireOS and 1 - indicates C9800.
        type: str
      hashKey:
        description: SSC hash string must be 40 characters.
        type: str
      memberMacAddress:
        description: Peer device mobility MAC Address. Allowed formats are 0a0b.0c01.0211,
          0a0b0c010211, 0a 0b 0c 01 02 11.
        type: str
      mobilityGroupName:
        description: Peer Device mobility group Name. Must be alphanumeric without {!,<,space,?/'}
          and maximum of 31 characters.
        type: str
      peerDeviceName:
        description: Peer device Host Name.
        type: str
      peerIp:
        description: This indicates public ip address.
        type: str
      peerNetworkDeviceId:
        description: The possible values are UNKNOWN or valid UUID of Network device
          Id. UNKNOWN represents out of band device which is not managed internally.
          Valid UUID represents WLC network device id.
        type: str
      privateIpAddress:
        description: This indicates private/management ip address.
        type: str
    type: list
  networkDeviceId:
    description: Obtain the network device ID value by using the API call GET /dna/intent/api/v1/network-device/ip-...
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Wireless MobilityProvisionV1
  description: Complete reference of the MobilityProvisionV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!mobility-provision
notes:
  - SDK Method used are
    wireless.Wireless.mobility_provision_v1,

  - Paths used are
    post /dna/intent/api/v1/wirelessControllers/wirelessMobilityGroups/mobilityProvision,

"""

EXAMPLES = r"""
- name: Create
  cisco.dnac.wireless_controllers_wireless_mobility_groups_mobility_provision_v1:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    dataLinkEncryption: true
    dtlsHighCipher: true
    macAddress: string
    managementIp: string
    mobilityGroupName: string
    mobilityPeers:
    - deviceSeries: string
      hashKey: string
      memberMacAddress: string
      mobilityGroupName: string
      peerDeviceName: string
      peerIp: string
      peerNetworkDeviceId: string
      privateIpAddress: string
    networkDeviceId: string

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_access_global_exception_rules
short_description: Resource module for Network Access Global Exception Rules
description:
- Manage operations create, update and delete of the resource Network Access Global Exception Rules.
- Network Access - Create global exception authorization rule.
- Network Access - Delete global exception authorization rule.
- Network Access - Update global exception authorization rule.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.ise.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Rule id.
    type: str
  link:
    description: Network Access Global Exception Rules's link.
    suboptions:
      href:
        description: Network Access Global Exception Rules's href.
        type: str
      rel:
        description: Network Access Global Exception Rules's rel.
        type: str
      type:
        description: Network Access Global Exception Rules's type.
        type: str
    type: dict
  profile:
    description: The authorization profile/s.
    elements: str
    type: list
  rule:
    description: Common attributes in rule authentication/authorization.
    suboptions:
      condition:
        description: Network Access Global Exception Rules's condition.
        suboptions:
          attributeId:
            description: Dictionary attribute id (Optional), used for additional verification.
            type: str
          attributeName:
            description: Dictionary attribute name.
            type: str
          attributeValue:
            description: <ul><li>Attribute value for condition</li> <li>Value type is
              specified in dictionary object</li> <li>if multiple values allowed is
              specified in dictionary object</li></ul>.
            type: str
          children:
            description: In case type is andBlock or orBlock addtional conditions will
              be aggregated under this logical (OR/AND) condition.
            elements: dict
            suboptions:
              conditionType:
                description: <ul><li>Inidicates whether the record is the condition
                  itself(data) or a logical(or,and) aggregation</li> <li>Data type enum(reference,single)
                  indicates than "conditonId" OR "ConditionAttrs" fields should contain
                  condition data but not both</li> <li>Logical aggreation(and,or) enum
                  indicates that additional conditions are present under the children
                  field</li></ul>.
                type: str
              isNegate:
                description: Indicates whereas this condition is in negate mode.
                type: bool
              link:
                description: Network Access Global Exception Rules's link.
                suboptions:
                  href:
                    description: Network Access Global Exception Rules's href.
                    type: str
                  rel:
                    description: Network Access Global Exception Rules's rel.
                    type: str
                  type:
                    description: Network Access Global Exception Rules's type.
                    type: str
                type: dict
            type: list
          conditionType:
            description: <ul><li>Inidicates whether the record is the condition itself(data)
              or a logical(or,and) aggregation</li> <li>Data type enum(reference,single)
              indicates than "conditonId" OR "ConditionAttrs" fields should contain
              condition data but not both</li> <li>Logical aggreation(and,or) enum indicates
              that additional conditions are present under the children field</li></ul>.
            type: str
          datesRange:
            description: <p>Defines for which date/s TimeAndDate condition will be matched
              or NOT matched if used in exceptionDates prooperty<br> Options are - Date
              range, for specific date, the same date should be used for start/end date
              <br> Default - no specific dates<br> In order to reset the dates to have
              no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
              = year)</p>.
            suboptions:
              endDate:
                description: Network Access Global Exception Rules's endDate.
                type: str
              startDate:
                description: Network Access Global Exception Rules's startDate.
                type: str
            type: dict
          datesRangeException:
            description: <p>Defines for which date/s TimeAndDate condition will be matched
              or NOT matched if used in exceptionDates prooperty<br> Options are - Date
              range, for specific date, the same date should be used for start/end date
              <br> Default - no specific dates<br> In order to reset the dates to have
              no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
              = year)</p>.
            suboptions:
              endDate:
                description: Network Access Global Exception Rules's endDate.
                type: str
              startDate:
                description: Network Access Global Exception Rules's startDate.
                type: str
            type: dict
          description:
            description: Condition description.
            type: str
          dictionaryName:
            description: Dictionary name.
            type: str
          dictionaryValue:
            description: Dictionary value.
            type: str
          hoursRange:
            description: <p>Defines for which hours a TimeAndDate condition will be
              matched or not matched if used in exceptionHours property<br> Time foramt
              - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
            suboptions:
              endTime:
                description: Network Access Global Exception Rules's endTime.
                type: str
              startTime:
                description: Network Access Global Exception Rules's startTime.
                type: str
            type: dict
          hoursRangeException:
            description: <p>Defines for which hours a TimeAndDate condition will be
              matched or not matched if used in exceptionHours property<br> Time foramt
              - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
            suboptions:
              endTime:
                description: Network Access Global Exception Rules's endTime.
                type: str
              startTime:
                description: Network Access Global Exception Rules's startTime.
                type: str
            type: dict
          id:
            description: Network Access Global Exception Rules's id.
            type: str
          isNegate:
            description: Indicates whereas this condition is in negate mode.
            type: bool
          link:
            description: Network Access Global Exception Rules's link.
            suboptions:
              href:
                description: Network Access Global Exception Rules's href.
                type: str
              rel:
                description: Network Access Global Exception Rules's rel.
                type: str
              type:
                description: Network Access Global Exception Rules's type.
                type: str
            type: dict
          name:
            description: Condition name.
            type: str
          operator:
            description: Equality operator.
            type: str
          weekDays:
            description: <p>Defines for which days this condition will be matched<br>
              Days format - Arrays of WeekDay enums <br> Default - List of All week
              days</p>.
            elements: str
            type: list
          weekDaysException:
            description: <p>Defines for which days this condition will NOT be matched<br>
              Days format - Arrays of WeekDay enums <br> Default - Not enabled</p>.
            elements: str
            type: list
        type: dict
      default:
        description: Indicates if this rule is the default one.
        type: bool
      hitCounts:
        description: The amount of times the rule was matched.
        type: int
      id:
        description: The identifier of the rule.
        type: str
      name:
        description: Rule name, Valid characters are alphanumerics, underscore, hyphen,
          space, period, parentheses.
        type: str
      rank:
        description: The rank(priority) in relation to other rules. Lower rank is higher
          priority.
        type: int
      state:
        description: The state that the rule is in. A disabled rule cannot be matched.
        type: str
    type: dict
  securityGroup:
    description: Security group used in authorization policies.
    type: str
requirements:
- ciscoisesdk >= 2.2.3
- python >= 3.5
seealso:
- name: Cisco ISE documentation for Network Access - Authorization Global Exception Rules
  description: Complete reference of the Network Access - Authorization Global Exception Rules API.
  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
notes:
  - SDK Method used are
    network_access_authorization_global_exception_rules.NetworkAccessAuthorizationGlobalExceptionRules.create_network_access_policy_set_global_exception_rule,
    network_access_authorization_global_exception_rules.NetworkAccessAuthorizationGlobalExceptionRules.delete_network_access_policy_set_global_exception_rule_by_id,
    network_access_authorization_global_exception_rules.NetworkAccessAuthorizationGlobalExceptionRules.update_network_access_policy_set_global_exception_rule_by_id,

  - Paths used are
    post /network-access/policy-set/global-exception,
    delete /network-access/policy-set/global-exception/{id},
    put /network-access/policy-set/global-exception/{id},

"""

EXAMPLES = r"""
- name: Create
  cisco.ise.network_access_global_exception_rules:
    ise_hostname: "{{ise_hostname}}"
    ise_username: "{{ise_username}}"
    ise_password: "{{ise_password}}"
    ise_verify: "{{ise_verify}}"
    state: present
    link:
      href: string
      rel: string
      type: string
    profile:
    - string
    rule:
      condition:
        attributeId: string
        attributeName: string
        attributeValue: string
        children:
        - conditionType: string
          isNegate: true
          link:
            href: string
            rel: string
            type: string
        conditionType: string
        datesRange:
          endDate: string
          startDate: string
        datesRangeException:
          endDate: string
          startDate: string
        description: string
        dictionaryName: string
        dictionaryValue: string
        hoursRange:
          endTime: string
          startTime: string
        hoursRangeException:
          endTime: string
          startTime: string
        id: string
        isNegate: true
        link:
          href: string
          rel: string
          type: string
        name: string
        operator: string
        weekDays:
        - string
        weekDaysException:
        - string
      default: true
      hitCounts: 0
      id: string
      name: string
      rank: 0
      state: string
    securityGroup: string

- name: Update by id
  cisco.ise.network_access_global_exception_rules:
    ise_hostname: "{{ise_hostname}}"
    ise_username: "{{ise_username}}"
    ise_password: "{{ise_password}}"
    ise_verify: "{{ise_verify}}"
    state: present
    id: string
    link:
      href: string
      rel: string
      type: string
    profile:
    - string
    rule:
      condition:
        attributeId: string
        attributeName: string
        attributeValue: string
        children:
        - conditionType: string
          isNegate: true
          link:
            href: string
            rel: string
            type: string
        conditionType: string
        datesRange:
          endDate: string
          startDate: string
        datesRangeException:
          endDate: string
          startDate: string
        description: string
        dictionaryName: string
        dictionaryValue: string
        hoursRange:
          endTime: string
          startTime: string
        hoursRangeException:
          endTime: string
          startTime: string
        id: string
        isNegate: true
        link:
          href: string
          rel: string
          type: string
        name: string
        operator: string
        weekDays:
        - string
        weekDaysException:
        - string
      default: true
      hitCounts: 0
      id: string
      name: string
      rank: 0
      state: string
    securityGroup: string

- name: Delete by id
  cisco.ise.network_access_global_exception_rules:
    ise_hostname: "{{ise_hostname}}"
    ise_username: "{{ise_username}}"
    ise_password: "{{ise_password}}"
    ise_verify: "{{ise_verify}}"
    state: absent
    id: string

"""

RETURN = r"""
ise_response:
  description: A dictionary or list with the response returned by the Cisco ISE Python SDK
  returned: always
  type: dict
  sample: >
    {
      "link": {
        "href": "string",
        "rel": "string",
        "type": "string"
      },
      "profile": [
        "string"
      ],
      "rule": {
        "condition": {
          "conditionType": "string",
          "isNegate": true,
          "link": {
            "href": "string",
            "rel": "string",
            "type": "string"
          },
          "description": "string",
          "id": "string",
          "name": "string",
          "attributeName": "string",
          "attributeId": "string",
          "attributeValue": "string",
          "dictionaryName": "string",
          "dictionaryValue": "string",
          "operator": "string",
          "children": [
            {
              "conditionType": "string",
              "isNegate": true,
              "link": {
                "href": "string",
                "rel": "string",
                "type": "string"
              }
            }
          ],
          "datesRange": {
            "endDate": "string",
            "startDate": "string"
          },
          "datesRangeException": {
            "endDate": "string",
            "startDate": "string"
          },
          "hoursRange": {
            "endTime": "string",
            "startTime": "string"
          },
          "hoursRangeException": {
            "endTime": "string",
            "startTime": "string"
          },
          "weekDays": [
            "string"
          ],
          "weekDaysException": [
            "string"
          ]
        },
        "default": true,
        "hitCounts": 0,
        "id": "string",
        "name": "string",
        "rank": 0,
        "state": "string"
      },
      "securityGroup": "string"
    }

ise_update_response:
  description: A dictionary or list with the response returned by the Cisco ISE Python SDK
  returned: always
  version_added: '1.1.0'
  type: dict
  sample: >
    {
      "response": {
        "link": {
          "href": "string",
          "rel": "string",
          "type": "string"
        },
        "profile": [
          "string"
        ],
        "rule": {
          "condition": {
            "conditionType": "string",
            "isNegate": true,
            "link": {
              "href": "string",
              "rel": "string",
              "type": "string"
            },
            "description": "string",
            "id": "string",
            "name": "string",
            "attributeName": "string",
            "attributeId": "string",
            "attributeValue": "string",
            "dictionaryName": "string",
            "dictionaryValue": "string",
            "operator": "string",
            "children": [
              {
                "conditionType": "string",
                "isNegate": true,
                "link": {
                  "href": "string",
                  "rel": "string",
                  "type": "string"
                }
              }
            ],
            "datesRange": {
              "endDate": "string",
              "startDate": "string"
            },
            "datesRangeException": {
              "endDate": "string",
              "startDate": "string"
            },
            "hoursRange": {
              "endTime": "string",
              "startTime": "string"
            },
            "hoursRangeException": {
              "endTime": "string",
              "startTime": "string"
            },
            "weekDays": [
              "string"
            ],
            "weekDaysException": [
              "string"
            ]
          },
          "default": true,
          "hitCounts": 0,
          "id": "string",
          "name": "string",
          "rank": 0,
          "state": "string"
        },
        "securityGroup": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)


DOCUMENTATION = r"""
---
module: golden_image_create
short_description: Resource module for Golden Image Create
description:
- This module represents an alias of the module golden_image_create_v1
version_added: '4.0.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deviceFamilyIdentifier:
    description: Device Family Identifier e.g. 277696480-283933147, 277696480.
    type: str
  deviceRole:
    description: Device Role. Permissible Values ALL, UNKNOWN, ACCESS, BORDER ROUTER,
      DISTRIBUTION and CORE.
    type: str
  imageId:
    description: ImageId in uuid format.
    type: str
  siteId:
    description: SiteId in uuid format. For Global Site "-1" to be used.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Software Image Management (SWIM) TagAsGoldenImageV1
  description: Complete reference of the TagAsGoldenImageV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!tag-as-golden-image
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.tag_as_golden_image_v1,

  - Paths used are
    post /dna/intent/api/v1/image/importation/golden,
  - It should be noted that this module is an alias of golden_image_create_v1

"""

EXAMPLES = r"""
- name: Create
  cisco.dnac.golden_image_create:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    deviceFamilyIdentifier: string
    deviceRole: string
    imageId: string
    siteId: string

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
#
# Copyright (c) 2022 xuzhang3 (@xuzhang3)
#                    XiuxiSun, (@Fred-sun)
#
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function
__metaclass__ = type


DOCUMENTATION = '''
---
module: azure_rm_virtualhubconnection_info
version_added: '1.14.0'
short_description: Get VirtualHub info
description:
    - Get info of VirtualHub.
options:
    resource_group:
        description:
            - The resource group name of the VirtualHub.
        type: str
        required: True
    virtual_hub_name:
        description:
            - The resource name of the VirtualHub.
        type: str
        required: True
    name:
        description:
            - The name of the VirtualHub connection.
        type: str
extends_documentation_fragment:
    - azure.azcollection.azure
author:
    - Fred-Sun (@Fred-Sun)
    - Xu Zhang (@xuzhang3)

'''

EXAMPLES = '''
- name: Get virtual hub connection info by name
  azure_rm_virtualhubconnection_info:
    resource_group: myResourceGroup
    virtual_hub_name: virtualHub
    name: vhubname

- name: Get virtual hub connection info by resource group
  azure_rm_virtualhubconnection_info:
    resource_group: myResourceGroup
    virtual_hub_name: virtualHub
'''

RETURN = '''
virtual_hub_connection:
    description:
        - A list of dict results for the virtual hub connection info.
    returned: always
    type: complex
    contains:
        id:
            description:
                - Resource ID.
            returned: always
            type: str
            sample: "/subscriptions/xxx-xxx/resourceGroups/myRG/providers/Microsoft.Network/virtualHubs/vhub/hubVirtualNetworkConnections/MyConnection"
        name:
            description:
                - Resource name.
            returned: always
            type: str
            sample: MyConnection
        etag:
            description:
                - A unique read-only string that changes whenever the resource is updated.
            returned: always
            type: str
            sample: 31102041-49e7-4cac-8573-aac1e1a16793
        remote_virtual_network:
            description:
                - Name of ID of the remote VNet to connect to.
            returned: always
            type: complex
            contains:
                id:
                    description:
                        - The ID of the remote VNet to connect to.
                    returned: always
                    type: str
                    sample: /subscriptions/xxx-xxx/resourceGroups/myRG/providers/Microsoft.Network/virtualNetworks/testvnet
        routing_configuration:
            description:
                - The routing configuration information
            returned: always
            type: complex
            contains:
                associated_route_table:
                    description:
                        - The resource ID of route table associated with this routing configuration.
                    type: complex
                    returned: always
                    contains:
                        id:
                            description:
                                - The ID of the routetable.
                            type: str
                            returned: always
                            sample: /subscriptions/xxx-xxx/resourceGroups/myRG/providers/Microsoft.Network/virtualHubs/testhub/hubRouteTables/rt_name
                propagated_route_tables:
                    description:
                        - Space-separated list of resource id of propagated route tables.
                    type: complex
                    returned: always
                    contains:
                        ids:
                            description:
                                - The list resource ID of propagated route tables.
                            type: list
                            returned: always
                            sample: [{id: '/subscriptions/xxx-xxx/resourceGroups/myRG/providers/Microsoft.Network/virtualHubs/testhub/hubRouteTables/rt_name'}]
                        labels:
                            description:
                                - Space-separated list of labels for propagated route tables.
                            type: list
                            returned: always
                            sample: ['labels1', 'labels2']
                vnet_routes:
                    description:
                        - The name of the Static Route that is unique within a Vnet Route.
                    returned: always
                    type: complex
                    contains:
                        static_routes:
                            description:
                                - The name of the Static Route.
                            type: list
                            returned: always
                            contains:
                                address_prefixes:
                                    description:
                                        - Space-separated list of all address prefixes.
                                    type: list
                                    returned: always
                                    sample: ["10.1.0.0/16", "10.2.0.0/16"]
                                name:
                                    description:
                                        - The name of static router.
                                    type: str
                                    returned: always
                                    sample: route1
                                next_hop_ip_address:
                                    description:
                                        - The next hop ip address.
                                    type: str
                                    returned: always
                                    sample: 10.0.0.65
        provisioning_state:
            description:
                - The provisioning state of the virtual hub connection resource.
            returned: always
            type: str
            sample: Succeeded
        allow_hub_to_remote_vnet_transit:
            description:
                - Enable hub to remote VNet transit.
            returned: always
            type: bool
            sample: true
        allow_remote_vnet_to_use_hub_vnet_gateways:
            description:
                - Allow remote VNet to use hub's VNet gateways.
            returned: always
            type: bool
            sample: true
        enable_internet_security:
            description:
                - Enable internet security and default is enabled.
            type: bool
            returned: always
            sample: true
'''

from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBase
try:
    from azure.core.exceptions import ResourceNotFoundError
except ImportError:
    # This is handled in azure_rm_common
    pass


class AzureRMVirtualHubConnectionInfo(AzureRMModuleBase):
    def __init__(self):
        self.module_arg_spec = dict(
            resource_group=dict(
                type='str',
                required=True
            ),
            name=dict(
                type='str'
            ),
            virtual_hub_name=dict(
                type='str',
                required=True
            )
        )

        self.resource_group = None
        self.name = None
        self.virtual_hub_name = None

        self.results = dict(changed=False)
        self.state = None
        self.status_code = [200]

        super(AzureRMVirtualHubConnectionInfo, self).__init__(self.module_arg_spec, supports_check_mode=True, supports_tags=False)

    def exec_module(self, **kwargs):

        for key in self.module_arg_spec:
            setattr(self, key, kwargs[key])

        if self.name is not None:
            self.results['virtual_hub_connection'] = self.format_item(self.get())
        else:
            self.results['virtual_hub_connection'] = self.format_item(self.list())
        return self.results

    def get(self):
        response = None

        try:
            response = self.network_client.hub_virtual_network_connections.get(resource_group_name=self.resource_group,
                                                                               virtual_hub_name=self.virtual_hub_name,
                                                                               connection_name=self.name)
        except ResourceNotFoundError:
            self.log('Could not get info for @(Model.ModuleOperationNameUpper).')

        return response

    def list(self):
        response = None

        try:
            response = self.network_client.hub_virtual_network_connections.list(resource_group_name=self.resource_group,
                                                                                virtual_hub_name=self.virtual_hub_name)
        except Exception:
            self.log('Could not get info for @(Model.ModuleOperationNameUpper).')

        return response

    def format_item(self, item):
        if item is None:
            return None
        elif hasattr(item, 'as_dict'):
            return [item.as_dict()]
        else:
            result = []
            items = list(item)
            for tmp in items:
                result.append(tmp.as_dict())
            return result


def main():
    AzureRMVirtualHubConnectionInfo()


if __name__ == '__main__':
    main()



#!/usr/bin/python
#
# Copyright (c) 2022 xuzhang3 (@xuzhang3)
#                    XiuxiSun, (@Fred-sun)
#
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function
__metaclass__ = type


DOCUMENTATION = '''
---
module: azure_rm_virtualhubconnection
version_added: '1.14.0'
short_description: Manage Azure VirtualHub instance
description:
    - Create, update and delete instance of Azure VirtualHub.
options:
    resource_group:
        description:
            - The resource group name of the VirtualHub.
        required: true
        type: str
    name:
        description:
            - The name of the VirtualHub connection.
        required: true
        type: str
    vhub_name:
        description:
            - The VirtualHub name.
        type: str
        required: True
    enable_internet_security:
        description:
            - Enable internet security.
        type: bool
    allow_remote_vnet_to_use_hub_vnet_gateways:
        description:
            - Allow RemoteVnet to use Virtual Hub's gateways.
        type: bool
    allow_hub_to_remote_vnet_transit:
        description:
            - VirtualHub to RemoteVnet transit to enabled or not.
        type: bool
    remote_virtual_network:
        description:
            - ID of the remote VNet to connect to.
        type: dict
        suboptions:
            id:
                description:
                    - The remote virtual network ID.
                type: str
    routing_configuration:
        description:
            - The Routing Configuration indicating the associated and propagated route tables on this connection.
        type: dict
        suboptions:
            propagated_route_tables:
                description:
                    - The list of RouteTables to advertise the routes to.
                type: dict
                suboptions:
                    labels:
                        description:
                            - The list of labels.
                        type: list
                        elements: str
                    ids:
                        description:
                            -The list of resource ids of all the virtual hub RouteTables.
                        type: list
                        elements: dict
                        suboptions:
                            id:
                                description:
                                    - The ID of the RouteTables.
                                type: str
            vnet_routes:
                description:
                    - List of routes that control routing from VirtualHub into a virtual network connection.
                type: dict
                suboptions:
                    static_routes:
                        description:
                            - List of all Static Routes.
                        type: list
                        elements: dict
                        suboptions:
                            name:
                                description:
                                    - The name of the StaticRoute that is unique within a VnetRoute.
                                type: str
                            address_prefixes:
                                description:
                                    - List of all address prefixes.
                                type: list
                                elements: str
                            next_hop_ip_address:
                                description:
                                    - The ip address of the next hop.
                                type: str
    state:
        description:
            - Assert the state of the VirtualHub connection.
            - Use C(present) to create or update an VirtualHub connection and C(absent) to delete it.
        default: present
        type: str
        choices:
            - absent
            - present
extends_documentation_fragment:
    - azure.azcollection.azure
author:
    - Fred-Sun (@Fred-Sun)
    - Xu Zhang (@xuzhang3)

'''

EXAMPLES = '''
- name: Create virtual hub connection
  azure_rm_virtualhubconnection:
    resource_group: myRG
    vhub_name: testhub
    name: Myconnection
    enable_internet_security: false
    allow_remote_vnet_to_use_hub_vnet_gateways: true
    allow_hub_to_remote_vnet_transit: true
    remote_virtual_network:
      id: /subscriptions/xxx-xxx/resourceGroups/myRG/providers/Microsoft.Network/virtualNetworks/testvnet
    routing_configuration:
      propagated_route_tables:
        labels:
          - labels1
          - labels3
        ids:
          - id: /subscriptions/xxx-xxx/resourceGroups/myRG/providers/Microsoft.Network/virtualHubs/testhub01/hubRouteTables/testtable
      vnet_routes:
        static_routes:
          - name: route1
            address_prefixes:
              - 10.1.0.0/16
              - 10.2.0.0/16
            next_hop_ip_address: 10.0.0.68
          - name: route2
            address_prefixes:
              - 10.4.0.0/16
            next_hop_ip_address: 10.0.0.65

- name: Delete virtual hub connection
  azure_rm_virtualhubconnection:
    resource_group: myRG
    vhub_name: testhub
    name: Myconnection
    state: absent
'''

RETURN = '''
state:
    description:
        - A list of dict results for the virtual hub connection info.
    returned: always
    type: complex
    contains:
        id:
            description:
                - Resource ID.
            returned: always
            type: str
            sample: /subscriptions/xxx-xxx/resourceGroups/myRG/providers/Microsoft.Network/virtualHubs/vhub/hubVirtualNetworkConnections/MyConnection
        name:
            description:
                - Resource name.
            returned: always
            type: str
            sample: MyConnection
        etag:
            description:
                - A unique read-only string that changes whenever the resource is updated.
            returned: always
            type: str
            sample: 31102041-49e7-4cac-8573-aac1e1a16793
        remote_virtual_network:
            description:
                - Name of ID of the remote VNet to connect to.
            returned: always
            type: complex
            contains:
                id:
                    description:
                        - The ID of the remote VNet to connect to.
                    returned: always
                    type: str
                    sample: /subscriptions/xxx-xxx/resourceGroups/myRG/providers/Microsoft.Network/virtualNetworks/testvnet
        routing_configuration:
            description:
                - The routing configuration information
            returned: always
            type: complex
            contains:
                associated_route_table:
                    description:
                        - The resource ID of route table associated with this routing configuration.
                    type: complex
                    returned: always
                    contains:
                        id:
                            description:
                                - The ID of the routetable.
                            type: str
                            returned: always
                            sample: /subscriptions/xxx-xxx/resourceGroups/myRG/providers/Microsoft.Network/virtualHubs/testhub/hubRouteTables/rt_name
                propagated_route_tables:
                    description:
                        - Space-separated list of resource id of propagated route tables.
                    type: complex
                    returned: always
                    contains:
                        ids:
                            description:
                                - The list resource ID of propagated route tables.
                            type: list
                            returned: always
                            sample: [{ id: '/subscriptions/xxx-xxx/resourceGroups/myRG/providers/Microsoft.Network/virtualHubs/testhub/hubRouteTables/rt_name'}]
                        labels:
                            description:
                                - Space-separated list of labels for propagated route tables.
                            type: list
                            returned: always
                            sample: ['labels1', 'labels2']
                vnet_routes:
                    description:
                        - The name of the Static Route that is unique within a Vnet Route.
                    returned: always
                    type: complex
                    contains:
                        static_routes:
                            description:
                                - The name of the Static Route.
                            type: list
                            returned: always
                            contains:
                                address_prefixes:
                                    description:
                                        - Space-separated list of all address prefixes.
                                    type: list
                                    returned: always
                                    sample: ["10.1.0.0/16", "10.2.0.0/16"]
                                name:
                                    description:
                                        - The name of static router.
                                    type: str
                                    returned: always
                                    sample: route1
                                next_hop_ip_address:
                                    description:
                                        - The next hop ip address.
                                    type: str
                                    returned: always
                                    sample: 10.0.0.65
        provisioning_state:
            description:
                - The provisioning state of the virtual hub connection resource.
            returned: always
            type: str
            sample: Succeeded
        allow_hub_to_remote_vnet_transit:
            description:
                - Enable hub to remote VNet transit.
            returned: always
            type: bool
            sample: true
        allow_remote_vnet_to_use_hub_vnet_gateways:
            description:
                - Allow remote VNet to use hub's VNet gateways.
            returned: always
            type: bool
            sample: true
        enable_internet_security:
            description:
                - Enable internet security and default is enabled.
            type: bool
            returned: always
            sample: true
'''

from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBaseExt
try:
    from azure.core.exceptions import ResourceNotFoundError
    from azure.core.polling import LROPoller
except ImportError:
    # This is handled in azure_rm_common
    pass


class Actions:
    NoAction, Create, Update, Delete = range(4)


static_routes_spec = dict(
    name=dict(type='str'),
    address_prefixes=dict(type='list', elements='str'),
    next_hop_ip_address=dict(type='str')
)


class AzureRMVirtualHubConnection(AzureRMModuleBaseExt):
    def __init__(self):
        self.module_arg_spec = dict(
            resource_group=dict(
                type='str',
                required=True
            ),
            vhub_name=dict(
                type='str',
                required=True
            ),
            name=dict(
                type='str',
                required=True
            ),
            enable_internet_security=dict(
                type='bool'
            ),
            allow_remote_vnet_to_use_hub_vnet_gateways=dict(
                type='bool'
            ),
            allow_hub_to_remote_vnet_transit=dict(
                type='bool'
            ),
            remote_virtual_network=dict(
                type='dict',
                options=dict(
                    id=dict(
                        type='str',
                    )
                )
            ),
            routing_configuration=dict(
                type='dict',
                options=dict(
                    propagated_route_tables=dict(
                        type='dict',
                        options=dict(
                            labels=dict(
                                type='list',
                                elements='str'
                            ),
                            ids=dict(
                                type='list',
                                elements='dict',
                                options=dict(
                                    id=dict(
                                        type='str',
                                    )
                                )
                            )
                        )
                    ),
                    vnet_routes=dict(
                        type='dict',
                        options=dict(
                            static_routes=dict(
                                type='list',
                                elements='dict',
                                options=static_routes_spec
                            )
                        )
                    )
                )
            ),
            state=dict(
                type='str',
                default='present',
                choices=['present', 'absent']
            )
        )

        self.resource_group = None
        self.vhub_name = None
        self.name = None
        self.body = {}

        self.results = dict(changed=False)
        self.state = None
        self.to_do = Actions.NoAction

        super(AzureRMVirtualHubConnection, self).__init__(derived_arg_spec=self.module_arg_spec,
                                                          supports_check_mode=True,
                                                          supports_tags=False)

    def exec_module(self, **kwargs):
        for key in list(self.module_arg_spec.keys()):
            if hasattr(self, key):
                setattr(self, key, kwargs[key])
            elif kwargs[key] is not None:
                self.body[key] = kwargs[key]

        self.inflate_parameters(self.module_arg_spec, self.body, 0)

        old_response = None
        response = None

        old_response = self.get_resource()

        if not old_response:
            if self.state == 'present':
                self.to_do = Actions.Create
        else:
            if self.state == 'absent':
                self.to_do = Actions.Delete
            else:
                if self.body.get('enable_internet_security') is not None:
                    if bool(self.body['enable_internet_security']) != bool(old_response['enable_internet_security']):
                        self.to_do = Actions.Update
                else:
                    self.body['enable_internet_security'] = old_response['enable_internet_security']
                if self.body.get('allow_remote_vnet_to_use_hub_vnet_gateways') is not None:
                    if bool(self.body['allow_remote_vnet_to_use_hub_vnet_gateways']) != bool(old_response['allow_remote_vnet_to_use_hub_vnet_gateways']):
                        self.to_do = Actions.Update
                else:
                    self.body['allow_remote_vnet_to_use_hub_vnet_gateways'] = old_response['allow_remote_vnet_to_use_hub_vnet_gateways']
                if self.body.get('allow_hub_to_remote_vnet_transit') is not None:
                    if bool(self.body['allow_hub_to_remote_vnet_transit']) != bool(old_response['allow_hub_to_remote_vnet_transit']):
                        self.to_do = Actions.Update
                else:
                    self.body['allow_hub_to_remote_vnet_transit'] = old_response['allow_hub_to_remote_vnet_transit']

                if self.body.get('routing_configuration') is not None:
                    modifiers = {}
                    self.create_compare_modifiers(self.module_arg_spec, '', modifiers)
                    self.results['modifiers'] = modifiers
                    self.results['compare'] = []
                    if not self.default_compare(modifiers, self.body['routing_configuration'], old_response['routing_configuration'], '', self.results):
                        self.to_do = Actions.Update
                    else:
                        self.body['routing_configuration'] = old_response['routing_configuration']
                else:
                    self.body['routing_configuration'] = old_response['routing_configuration']

        if (self.to_do == Actions.Create) or (self.to_do == Actions.Update):
            self.results['changed'] = True
            if self.check_mode:
                return self.results
            response = self.create_update_resource()
        elif self.to_do == Actions.Delete:
            self.results['changed'] = True
            if self.check_mode:
                return self.results
            self.delete_resource()
        else:
            self.results['changed'] = False
            response = old_response

        if response is not None:
            self.results['state'] = response

        return self.results

    def create_update_resource(self):
        try:
            response = self.network_client.hub_virtual_network_connections.begin_create_or_update(resource_group_name=self.resource_group,
                                                                                                  virtual_hub_name=self.vhub_name,
                                                                                                  connection_name=self.name,
                                                                                                  hub_virtual_network_connection_parameters=self.body)
            if isinstance(response, LROPoller):
                response = self.get_poller_result(response)
        except Exception as exc:
            self.log('Error attempting to create the VirtualHub instance.')
            self.fail('Error creating the VirtualHub instance: {0}'.format(str(exc)))
        return response.as_dict()

    def delete_resource(self):
        try:
            response = self.network_client.hub_virtual_network_connections.begin_delete(resource_group_name=self.resource_group,
                                                                                        virtual_hub_name=self.vhub_name,
                                                                                        connection_name=self.name)
        except Exception as e:
            self.log('Error attempting to delete the VirtualHub connection instance.')
            self.fail('Error deleting the VirtualHub connection instance: {0}'.format(str(e)))

        return True

    def get_resource(self):
        try:
            response = self.network_client.hub_virtual_network_connections.get(resource_group_name=self.resource_group,
                                                                               virtual_hub_name=self.vhub_name,
                                                                               connection_name=self.name)
        except ResourceNotFoundError as e:
            return False
        return response.as_dict()


def main():
    AzureRMVirtualHubConnection()


if __name__ == '__main__':
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: device_replacement_v1
short_description: Resource module for Device Replacement V1
description:
- Manage operations create and update of the resource Device Replacement V1.
- Marks device for replacement.
- UnMarks device for replacement.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Device Replacement's payload.
    elements: dict
    suboptions:
      creationTime:
        description: Date and time of marking the device for replacement.
        type: int
      family:
        description: Faulty device family.
        type: str
      faultyDeviceId:
        description: Unique identifier of the faulty device.
        type: str
      faultyDeviceName:
        description: Faulty device name.
        type: str
      faultyDevicePlatform:
        description: Faulty device platform.
        type: str
      faultyDeviceSerialNumber:
        description: Faulty device serial number.
        type: str
      id:
        description: Unique identifier of the device replacement resource.
        type: str
      neighbourDeviceId:
        description: Unique identifier of the neighbor device to create the DHCP server.
        type: str
      networkReadinessTaskId:
        description: Unique identifier of network readiness task.
        type: str
      replacementDevicePlatform:
        description: Replacement device platform.
        type: str
      replacementDeviceSerialNumber:
        description: Replacement device serial number.
        type: str
      replacementStatus:
        description: Device replacement status. Use NON-FAULTY to unmark the device
          for replacement.
        type: str
      replacementTime:
        description: Date and time of device replacement.
        type: int
      workflowId:
        description: Unique identifier of the device replacement workflow.
        type: str
    type: list
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Device Replacement MarkDeviceForReplacementV1
  description: Complete reference of the MarkDeviceForReplacementV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!mark-device-for-replacement
- name: Cisco DNA Center documentation for Device Replacement UnMarkDeviceForReplacementV1
  description: Complete reference of the UnMarkDeviceForReplacementV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!un-mark-device-for-replacement
notes:
  - SDK Method used are
    device_replacement.DeviceReplacement.mark_device_for_replacement_v1,
    device_replacement.DeviceReplacement.unmark_device_for_replacement_v1,

  - Paths used are
    post /dna/intent/api/v1/device-replacement,
    put /dna/intent/api/v1/device-replacement,

"""

EXAMPLES = r"""
- name: Update all
  cisco.dnac.device_replacement_v1:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
    - creationTime: 0
      family: string
      faultyDeviceId: string
      faultyDeviceName: string
      faultyDevicePlatform: string
      faultyDeviceSerialNumber: string
      id: string
      neighbourDeviceId: string
      networkReadinessTaskId: string
      replacementDevicePlatform: string
      replacementDeviceSerialNumber: string
      replacementStatus: string
      replacementTime: 0
      workflowId: string

- name: Create
  cisco.dnac.device_replacement_v1:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
    - creationTime: 0
      family: string
      faultyDeviceId: string
      faultyDeviceName: string
      faultyDevicePlatform: string
      faultyDeviceSerialNumber: string
      id: string
      neighbourDeviceId: string
      networkReadinessTaskId: string
      replacementDevicePlatform: string
      replacementDeviceSerialNumber: string
      replacementStatus: string
      replacementTime: 0
      workflowId: string

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: reserve_ip_subpool_v1_info
short_description: Information module for Reserve Ip Subpool V1
description:
- Get all Reserve Ip Subpool V1.
- API to get the ip subpool info.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  siteId:
    description:
    - >
      SiteId query parameter. Site id of site from which to retrieve associated reserve pools. Either siteId (per
      site queries) or ignoreInheritedGroups must be used. They can also be used together.
    type: str
  offset:
    description:
    - Offset query parameter. Offset/starting row. Indexed from 1.
    type: float
  limit:
    description:
    - >
      Limit query parameter. Number of reserve pools to be retrieved. Default is 25 if not specified. Maximum
      allowed limit is 500.
    type: float
  ignoreInheritedGroups:
    description:
    - >
      IgnoreInheritedGroups query parameter. Ignores pools inherited from parent site. Either siteId or
      ignoreInheritedGroups must be passed. They can also be used together.
    type: str
  poolUsage:
    description:
    - PoolUsage query parameter. Can take values empty, partially-full or empty-partially-full.
    type: str
  groupName:
    description:
    - GroupName query parameter. Name of the group.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Network Settings GetReserveIPSubpoolV1
  description: Complete reference of the GetReserveIPSubpoolV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!get-reserve-ip-subpool
notes:
  - SDK Method used are
    network_settings.NetworkSettings.get_reserve_ip_subpool_v1,

  - Paths used are
    get /dna/intent/api/v1/reserve-ip-subpool,

"""

EXAMPLES = r"""
- name: Get all Reserve Ip Subpool V1
  cisco.dnac.reserve_ip_subpool_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    siteId: string
    offset: 0
    limit: 0
    ignoreInheritedGroups: string
    poolUsage: string
    groupName: string
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "groupName": "string",
          "ipPools": [
            {
              "ipPoolName": "string",
              "dhcpServerIps": [
                {}
              ],
              "gateways": [
                "string"
              ],
              "createTime": 0,
              "lastUpdateTime": 0,
              "totalIpAddressCount": 0,
              "usedIpAddressCount": 0,
              "parentUuid": "string",
              "owner": "string",
              "shared": true,
              "overlapping": true,
              "configureExternalDhcp": true,
              "usedPercentage": "string",
              "clientOptions": {},
              "groupUuid": "string",
              "dnsServerIps": [
                {}
              ],
              "context": [
                {
                  "owner": "string",
                  "contextKey": "string",
                  "contextValue": "string"
                }
              ],
              "ipv6": true,
              "id": "string",
              "ipPoolCidr": "string"
            }
          ],
          "siteId": "string",
          "siteHierarchy": "string",
          "type": "string",
          "groupOwner": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: px_grid_direct_info
short_description: Information module for Px Grid Direct Info
description:
- Get all Px Grid Direct Info.
- Get Px Grid Direct Info by name.
- PxGrid Direct - Get ALL connectorConfig information.
- PxGrid Direct - Get connectorConfig information based on ConnectorName.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.ise.module_info
author: Rafael Campos (@racampos)
options:
  connectorName:
    description:
    - ConnectorName path parameter. Update or delete or retrieve the connector config.
    type: str
requirements:
- ciscoisesdk >= 2.2.3
- python >= 3.5
notes:
  - SDK Method used are
    px_grid_direct.PxGridDirect.get_connector_config,
    px_grid_direct.PxGridDirect.get_connector_config_by_connector_name,

  - Paths used are
    get /api/v1/pxgrid-direct/connector-config,
    get /api/v1/pxgrid-direct/connector-config/{connectorName},

"""

EXAMPLES = r"""
- name: Get all Px Grid Direct Info
  cisco.ise.px_grid_direct_info:
    ise_hostname: "{{ise_hostname}}"
    ise_username: "{{ise_username}}"
    ise_password: "{{ise_password}}"
    ise_verify: "{{ise_verify}}"
  register: result

- name: Get Px Grid Direct Info by name
  cisco.ise.px_grid_direct_info:
    ise_hostname: "{{ise_hostname}}"
    ise_username: "{{ise_username}}"
    ise_password: "{{ise_password}}"
    ise_verify: "{{ise_verify}}"
    connectorName: string
  register: result

"""

RETURN = r"""
ise_response:
  description: A dictionary or list with the response returned by the Cisco ISE Python SDK
  returned: always
  type: dict
  sample: >
    {
      "connector": {
        "additionalProperties": {},
        "attributes": {
          "attributeMapping": [
            {
              "dictionaryAttribute": "string",
              "includeInDictionary": true,
              "jsonAttribute": "string"
            }
          ],
          "correlationIdentifier": "string",
          "topLevelObject": "string",
          "uniqueIdentifier": "string",
          "versionIdentifier": "string"
        },
        "connectorName": "string",
        "connectorType": "string",
        "deltasyncSchedule": {
          "interval": 0,
          "intervalUnit": "string",
          "startDate": "string"
        },
        "description": "string",
        "enabled": true,
        "fullsyncSchedule": {
          "interval": 0,
          "intervalUnit": "string",
          "startDate": "string"
        },
        "protocol": "string",
        "skipCertificateValidations": true,
        "url": {
          "authenticationType": "string",
          "bulkUrl": "string",
          "incrementalUrl": "string",
          "password": "string",
          "userName": "string"
        }
      }
    }
"""



# -*- coding: utf-8 -*-

# Copyright: Contributors to the Ansible project
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from ..retries import AWSRetry

# from .common import AnsibleAutoScalingError
from .common import AutoScalingErrorHandler


@AutoScalingErrorHandler.list_error_handler("list auto scaling groups", default_value=[])
@AWSRetry.jittered_backoff()
def describe_auto_scaling_groups(client, group_names=None, filters=None):
    args = {}
    if group_names:
        args["AutoScalingGroupNames"] = group_names
    if filters:
        args["Filters"] = filters

    paginator = client.get_paginator("describe_auto_scaling_groups")
    return paginator.paginate(**args).build_full_result()["AutoScalingGroups"]



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: snmp_properties_v1
short_description: Resource module for Snmp Properties V1
description:
- Manage operation create of the resource Snmp Properties V1.
- Adds SNMP properties.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Snmp Properties's payload.
    elements: dict
    suboptions:
      id:
        description: Snmp Properties's id.
        type: str
      instanceTenantId:
        description: Snmp Properties's instanceTenantId.
        type: str
      instanceUuid:
        description: Snmp Properties's instanceUuid.
        type: str
      intValue:
        description: Snmp Properties's intValue.
        type: int
      systemPropertyName:
        description: Snmp Properties's systemPropertyName.
        type: str
    type: list
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Discovery CreateUpdateSNMPPropertiesV1
  description: Complete reference of the CreateUpdateSNMPPropertiesV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!create-update-snmp-properties
notes:
  - SDK Method used are
    discovery.Discovery.create_update_snmp_properties_v1,

  - Paths used are
    post /dna/intent/api/v1/snmp-property,

"""

EXAMPLES = r"""
- name: Create
  cisco.dnac.snmp_properties_v1:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
    - id: string
      instanceTenantId: string
      instanceUuid: string
      intValue: 0
      systemPropertyName: string

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: trusted_certificate
short_description: Resource module for Trusted Certificate
description:
- Manage operations update and delete of the resource Trusted Certificate.
- This API deletes a Trust Certificate from Trusted Certificate Store based on a given ID.
- Update a trusted certificate present in Cisco ISE trust store.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.ise.module
author: Rafael Campos (@racampos)
options:
  authenticateBeforeCRLReceived:
    description: Switch to enable or disable CRL verification if CRL is not received.
    type: bool
  automaticCRLUpdate:
    description: Switch to enable or disable automatic CRL update.
    type: bool
  automaticCRLUpdatePeriod:
    description: Automatic CRL update period.
    type: int
  automaticCRLUpdateUnits:
    description: Unit of time for automatic CRL update.
    type: str
  crlDistributionUrl:
    description: CRL Distribution URL.
    type: str
  crlDownloadFailureRetries:
    description: If CRL download fails, wait time before retry.
    type: int
  crlDownloadFailureRetriesUnits:
    description: Unit of time before retry if CRL download fails.
    type: str
  description:
    description: Description for trust certificate.
    type: str
  downloadCRL:
    description: Switch to enable or disable download of CRL.
    type: bool
  enableOCSPValidation:
    description: Switch to enable or disable OCSP Validation.
    type: bool
  enableServerIdentityCheck:
    description: Switch to enable or disable verification if HTTPS or LDAP server certificate
      name fits the configured server URL.
    type: bool
  id:
    description: Id path parameter. ID of the trust certificate.
    type: str
  ignoreCRLExpiration:
    description: Switch to enable or disable ignore CRL expiration.
    type: bool
  name:
    description: Friendly name of the certificate.
    type: str
  nonAutomaticCRLUpdatePeriod:
    description: Non automatic CRL update period.
    type: int
  nonAutomaticCRLUpdateUnits:
    description: Unit of time of non automatic CRL update.
    type: str
  rejectIfNoStatusFromOCSP:
    description: Switch to reject certificate if there is no status from OCSP.
    type: bool
  rejectIfUnreachableFromOCSP:
    description: Switch to reject certificate if unreachable from OCSP.
    type: bool
  selectedOCSPService:
    description: Name of selected OCSP Service.
    type: str
  status:
    description: Trusted Certificate's status.
    type: str
  trustForCertificateBasedAdminAuth:
    description: Trust for Certificate based Admin authentication.
    type: bool
  trustForCiscoServicesAuth:
    description: Trust for authentication of Cisco Services.
    type: bool
  trustForClientAuth:
    description: Trust for client authentication and Syslog.
    type: bool
  trustForIseAuth:
    description: Trust for authentication within Cisco ISE.
    type: bool
requirements:
- ciscoisesdk >= 2.2.3
- python >= 3.5
seealso:
- name: Cisco ISE documentation for Certificates
  description: Complete reference of the Certificates API.
  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!certificate-openapi
notes:
  - SDK Method used are
    certificates.Certificates.delete_trusted_certificate_by_id,
    certificates.Certificates.update_trusted_certificate,

  - Paths used are
    delete /api/v1/certs/trusted-certificate/{id},
    put /api/v1/certs/trusted-certificate/{id},

"""

EXAMPLES = r"""
- name: Update by id
  cisco.ise.trusted_certificate:
    ise_hostname: "{{ise_hostname}}"
    ise_username: "{{ise_username}}"
    ise_password: "{{ise_password}}"
    ise_verify: "{{ise_verify}}"
    state: present
    authenticateBeforeCRLReceived: true
    automaticCRLUpdate: true
    automaticCRLUpdatePeriod: 0
    automaticCRLUpdateUnits: string
    crlDistributionUrl: string
    crlDownloadFailureRetries: 0
    crlDownloadFailureRetriesUnits: string
    description: string
    downloadCRL: true
    enableOCSPValidation: true
    enableServerIdentityCheck: true
    id: string
    ignoreCRLExpiration: true
    name: string
    nonAutomaticCRLUpdatePeriod: 0
    nonAutomaticCRLUpdateUnits: string
    rejectIfNoStatusFromOCSP: true
    rejectIfUnreachableFromOCSP: true
    selectedOCSPService: string
    status: string
    trustForCertificateBasedAdminAuth: true
    trustForCiscoServicesAuth: true
    trustForClientAuth: true
    trustForIseAuth: true

- name: Delete by id
  cisco.ise.trusted_certificate:
    ise_hostname: "{{ise_hostname}}"
    ise_username: "{{ise_username}}"
    ise_password: "{{ise_password}}"
    ise_verify: "{{ise_verify}}"
    state: absent
    id: string

"""

RETURN = r"""
ise_response:
  description: A dictionary or list with the response returned by the Cisco ISE Python SDK
  returned: always
  type: dict
  sample: >
    {
      "authenticateBeforeCRLReceived": "string",
      "automaticCRLUpdate": "string",
      "automaticCRLUpdatePeriod": "string",
      "automaticCRLUpdateUnits": "string",
      "crlDistributionUrl": "string",
      "crlDownloadFailureRetries": "string",
      "crlDownloadFailureRetriesUnits": "string",
      "description": "string",
      "downloadCRL": "string",
      "enableOCSPValidation": "string",
      "enableServerIdentityCheck": "string",
      "expirationDate": "string",
      "friendlyName": "string",
      "id": "string",
      "ignoreCRLExpiration": "string",
      "internalCA": true,
      "isReferredInPolicy": true,
      "issuedBy": "string",
      "issuedTo": "string",
      "keySize": "string",
      "link": {
        "href": "string",
        "rel": "string",
        "type": "string"
      },
      "nonAutomaticCRLUpdatePeriod": "string",
      "nonAutomaticCRLUpdateUnits": "string",
      "rejectIfNoStatusFromOCSP": "string",
      "rejectIfUnreachableFromOCSP": "string",
      "selectedOCSPService": "string",
      "serialNumberDecimalFormat": "string",
      "sha256Fingerprint": "string",
      "signatureAlgorithm": "string",
      "status": "string",
      "subject": "string",
      "trustedFor": "string",
      "validFrom": "string"
    }

ise_update_response:
  description: A dictionary or list with the response returned by the Cisco ISE Python SDK
  returned: always
  version_added: '1.1.0'
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "link": {
          "href": "string",
          "rel": "string",
          "type": "string"
        },
        "message": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: support_bundle_download
short_description: Resource module for Support Bundle Download
description:
- Manage operation update of the resource Support Bundle Download.
- This API allows the client to upload a support bundle.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.ise.module
author: Rafael Campos (@racampos)
options:
  dirPath:
    description: Directory absolute path. Defaults to the current working directory.
    type: str
  fileName:
    description: Support Bundle Download's fileName.
    type: str
  saveFile:
    description: Enable or disable automatic file creation of raw response.
    type: bool
requirements:
- ciscoisesdk >= 2.2.3
- python >= 3.5
notes:
  - SDK Method used are
    support_bundle_download.SupportBundleDownload.download_support_bundle,

  - Paths used are
    put /ers/config/supportbundledownload,

"""

EXAMPLES = r"""
- name: Update all
  cisco.ise.support_bundle_download:
    ise_hostname: "{{ise_hostname}}"
    ise_username: "{{ise_username}}"
    ise_password: "{{ise_password}}"
    ise_verify: "{{ise_verify}}"
    dirPath: /tmp/downloads/
    fileName: download_filename.extension
    saveFile: true

"""

RETURN = r"""
ise_response:
  description: A dictionary or list with the response returned by the Cisco ISE Python SDK
  returned: always
  type: dict
  sample: >
    {
      "data": "fileContent",
      "filename": "fileName",
      "dirpath": "download/directory",
      "path": "download/directory/fileName"
    }
"""
